<?php

use Gtg_Advanced_Blocks\Plugin as Plugin;

defined( 'ABSPATH' ) || exit();

/**
 * Is Gutenberg plugin installed.
 */
if ( ! function_exists( 'gtg_is_gutenberg_installed' ) ) {

	/**
	 * Check if Gutenberg Pro is installed
	 *
	 * @param string $plugin_path Plugin path.
	 * @return boolean true | false
	 * @access public
	 * @since  1.0.0
	 *
	 */
	function gtg_is_gutenberg_installed( $plugin_path ) {
		$plugins = get_plugins();

		return isset( $plugins[ $plugin_path ] );
	}
}

if ( ! function_exists( 'gtg_block_factory' ) ) {

	function gtg_block_factory() {
		return Plugin::instance()->block_factory;
	}

}

if ( ! function_exists( 'gtg_load_fontawesome_icons' ) ) {
	/**
	 * Get Json Data.
	 *
	 * @return Array
	 * @since 1.0.0
	 */
	function gtg_load_fontawesome_icons() {
		if ( ! function_exists( 'WP_Filesystem' ) ) {
			require_once ABSPATH . 'wp-admin/includes/file.php';
		}

		WP_Filesystem();
		global $wp_filesystem;
		$fontawesome_file = GTG_AB_DIR . 'assets/libs/fontawesome-icons.json';
		$icons = json_decode( $wp_filesystem->get_contents( $fontawesome_file ), true );
		return apply_filters( 'gutengeek_load_fontawesome_icons', $icons );
	}
}

if ( ! function_exists( 'gtg_sanitize_value' ) ) {

	/**
	 * sanitize attributes values
	 *
	 * @param $value
	 * @return $values
	 */
	function gtg_sanitize_value( $value ) {
		if ( is_string( $value ) ) {
			return $value;
		} else if ( is_numeric( $value ) ) {
			return sanitize_text_field( $value );
		} else if ( is_array( $value ) ) {
			foreach ( $value as $key => $val ) {
				$value[$key] = gtg_sanitize_value( $val );
			}
			return $value;
		}
		return $value;
	}
}

if ( ! function_exists( 'gtg_render_svg_html' ) ) {

	/**
	 * Generate SVG.
	 *
	 * @param array $icon Decoded fontawesome json file data.
	 * @return string
	 * @since 1.0.0
	 */
	function gtg_render_svg_html( $icon ) {
		$icon = str_replace( 'far', '', $icon );
		$icon = str_replace( 'fas', '', $icon );
		$icon = str_replace( 'fab', '', $icon );
		$icon = str_replace( 'fa-', '', $icon );
		$icon = str_replace( 'fa', '', $icon );

		$html = '';
		if ( is_string($icon) ) {
			$icon = sanitize_text_field( esc_attr( $icon ) );
		} else if ( is_array( $icon ) && isset( $icon['lib'] ) && ! empty( $icon['value'] )) {
			$icon_name = trim($icon['value']);
			$lib = $icon['lib'];
			if ($lib === 'fontawesome') {
				$json = gtg_load_fontawesome_icons();
				$path = isset( $json[ $icon_name ]['svg']['brands'] ) ? $json[ $icon_name ]['svg']['brands']['path'] : $json[ $icon_name ]['svg']['solid']['path'];
				$view = isset( $json[ $icon_name ], $json[ $icon_name ]['svg'], $json[ $icon_name ]['svg']['brands'], $json[ $icon_name ]['svg']['viewBox'] ) ? $json[ $icon_name ]['svg']['brands']['viewBox'] : $json[ $icon_name ]['svg']['solid']['viewBox'];
				if ( $view ) {
					$view = implode( ' ', $view );
				}
				$html = '<svg xmlns="http://www.w3.org/2000/svg" viewBox="' . $view . '"><path d="' . $path . '"></path></svg>';
			} else {
				$custom_icons = gtg_get_custom_icons();
				if ( ! empty($custom_icons[$lib]) && ! empty( $custom_icons[$lib]['icons'] ) && ! empty( $custom_icons[$lib]['icons'][$icon_name] )) {
					$html = ! empty( $custom_icons[$lib]['icons'][$icon_name]['svg'] ) ? $custom_icons[$lib]['icons'][$icon_name]['svg'] : '';
				}
			}
		}

		return apply_filters( 'gutengeek_render_svg_html', $html, $icon );
	}
}

if ( ! function_exists( 'gtg_get_image_sizes' ) ) {

	/**
	 * Get size information for all currently-registered image sizes.
	 *
	 * @return array $sizes Data for all currently-registered image sizes.
	 * @uses   get_intermediate_image_sizes()
	 * @link   https://codex.wordpress.org/Function_Reference/get_intermediate_image_sizes
	 * @since  1.9.0
	 * @global $_wp_additional_image_sizes
	 */
	function gtg_get_image_sizes() {

		global $_wp_additional_image_sizes;

		$sizes       = get_intermediate_image_sizes();
		$image_sizes = [];

		$image_sizes[] = [
			'value' => 'full',
			'label' => esc_html__( 'Full', 'gutengeek' ),
		];

		foreach ( $sizes as $size ) {
			if ( in_array( $size, [ 'thumbnail', 'medium', 'medium_large', 'large' ] ) ) {
				$image_sizes[] = [
					'value' => $size,
					'label' => ucwords( trim( str_replace( [ '-', '_' ], [ ' ', ' ' ], $size ) ) ),
				];
			} else {
				$image_sizes[] = [
					'value' => $size,
					'label' => sprintf(
						'%1$s (%2$sx%3$s)',
						ucwords( trim( str_replace( [ '-', '_' ], [ ' ', ' ' ], $size ) ) ),
						$_wp_additional_image_sizes[ $size ]['width'],
						$_wp_additional_image_sizes[ $size ]['height']
					),
				];
			}
		}

		return apply_filters( 'gutengeek_post_featured_image_sizes', $image_sizes );
	}
}


if ( ! function_exists( 'gtg_get_post_types' ) ) {

	/**
	 * Get Post Types.
	 *
	 * @since  1.0.0
	 * @access public
	 */
	function gtg_get_post_types() {

		$post_types = get_post_types(
			[
				'public'       => true,
				'show_in_rest' => true,
			],
			'objects'
		);

		$options = [];

		foreach ( $post_types as $post_type ) {
			if ( 'product' == $post_type->name ) {
				continue;
			}

			$options[] = [
				'value' => $post_type->name,
				'label' => $post_type->label,
			];
		}

		return apply_filters( 'gutengeek_loop_post_types', $options );
	}
}

if ( ! function_exists( 'gtg_get_related_taxonomy' ) ) {

	/**
	 * Get all taxonomies.
	 *
	 * @since  1.0.0
	 * @access public
	 */
	function gtg_get_related_taxonomy() {
		$post_types = gtg_get_post_types();

		$return_array = [];
		foreach ( $post_types as $key => $value ) {
			$post_type = $value['value'];

			$taxonomies = get_object_taxonomies( $post_type, 'objects' );
			$data       = [];

			foreach ( $taxonomies as $tax_slug => $tax ) {
				if ( ! $tax->public || ! $tax->show_ui ) {
					continue;
				}

				$data[ $tax_slug ] = $tax;

				$terms = get_terms( $tax_slug );

				$related_tax = [];

				if ( ! empty( $terms ) ) {
					foreach ( $terms as $t_index => $t_obj ) {
						$related_tax[] = [
							'id'   => $t_obj->term_id,
							'slug' => $t_obj->slug,
							'name' => $t_obj->name,
						];
					}

					$return_array[ $post_type ]['terms'][ $tax_slug ] = $related_tax;
				}
			}

			$return_array[ $post_type ]['taxonomy'] = $data;
		}

		return apply_filters( 'gutengeek_post_loop_taxonomies', $return_array );
	}
}

if ( ! function_exists( 'gtg_parse_blocks' ) ) {

	/**
	 * Parse Guten Block.
	 *
	 * @param string $content the content string.
	 *
	 * @param        $content
	 * @return array
	 */
	function gtg_parse_blocks( $content ) {
		global $wp_version;

		return ( version_compare( $wp_version, '5', '>=' ) ) ? parse_blocks( $content ) : gutenberg_parse_blocks( $content );
	}

}

if ( ! function_exists( 'gtg_build_query' ) ) {

	/**
	 * build WP_Query
	 *
	 * @param $attributes
	 * @param $block_type
	 * @return WP_Query
	 */
	function gtg_build_query( $attributes, $block_type ) {
		global $wp_query;

		$paged = ( get_query_var( 'paged' ) ) ? get_query_var( 'paged' ) : 1;
		$paged = isset( $wp_query->query['paged'] ) ? $wp_query->query['paged'] : $paged;
		$paged = ! empty( $_REQUEST['paged'] ) ? absint( $_REQUEST['paged'] ) : $paged;

		if ( isset( $_GET['paged'] ) && intval( $_GET['paged'] ) > 0 ) {
			$paged = intval( $_GET['paged'] );
		}

		$query_args = [
			'posts_per_page'      => ( isset( $attributes['numberOfPosts'] ) ) ? $attributes['numberOfPosts'] : 6,
			'paged'               => isset( $attributes['paged'] ) && $attributes['paged'] ? absint( $attributes['paged'] ) : $paged,
			'post_status'         => 'publish',
			'post_type'           => ( isset( $attributes['postType'] ) ) ? $attributes['postType'] : 'post',
			'order'               => ( isset( $attributes['order'] ) ) ? $attributes['order'] : 'desc',
			'orderby'             => ( isset( $attributes['orderBy'] ) ) ? $attributes['orderBy'] : 'date',
			'ignore_sticky_posts' => 1,
		];

		if ( isset( $attributes['categories'] ) && '' != $attributes['categories'] ) {
			$query_args['tax_query'][] = [
				'taxonomy' => isset( $attributes['taxonomyType'] ) ? $attributes['taxonomyType'] : 'category',
				'field'    => 'slug',
				'terms'    => $attributes['categories'],
				'operator' => 'IN',
			];
		}

		$query_args = apply_filters( "gutengeek_post_query_args_{$block_type}", $query_args );

		return new WP_Query( $query_args );
	}
}

if ( ! function_exists( 'gtg_get_option' ) ) {

	function gtg_get_option( $key, $default = false, $network_override = false ) {
		// is network
		if ( $network_override && is_multisite() ) {
			$value = get_site_option( $key, $default );
		} else {
			$value = get_option( $key, $default );
		}

		return apply_filters( 'gutengeek_get_option', $value, $key, $default, $network_override );
	}

}

if ( ! function_exists( 'gtg_update_option' ) ) {

	function gtg_update_option( $key, $value, $network = false ) {
		// Update the site-wide option since we're in the network admin.
		if ( $network && is_multisite() ) {
			update_site_option( $key, $value );
		} else {
			update_option( $key, $value );
		}
	}

}
// TEMPLATE TIMELINE BLOCK

if ( ! function_exists( 'gtg_timeline_get_classes' ) ) {
	/**
	 * Function Name: gtg_timeline_get_classes .
	 *
	 * @param array $attributes array of setting.
	 * @return string             class name.
	 */
	function gtg_timeline_get_classes( $attributes ) {

		// Arrow position.
		$arrow_align_class = 'gutengeek-timeline-arrow-top' . ' ';
		if ( isset($attributes['arrowAlignment']) && 'center' === $attributes['arrowAlignment'] ) {
			$arrow_align_class = 'gutengeek-timeline-arrow-center' . ' ';
		} elseif ( isset($attributes['arrowAlignment']) && 'bottom' === $attributes['arrowAlignment'] ) {
			$arrow_align_class = 'gutengeek-timeline-arrow-bottom' . ' ';
		}

		// Alignmnet.
		$align_class = 'gutengeek-timeline-center-block ' . ' ';

		if ( isset($attributes['layout']) && 'left' === $attributes['layout'] ) {
			$align_class = 'gutengeek-timeline-left-block' . ' ';
		} elseif ( isset($attributes['layout']) && 'right' === $attributes['layout'] ) {
			$align_class = 'gutengeek-timeline-right-block' . ' ';
		}

		$stack = ! empty($attributes['stack']) ? $attributes['stack'] : 'tablet';
		$align_class .= $arrow_align_class . '';
		$align_class .= 'gutengeek-timeline-responsive-' . $stack . ' gutengeek-timeline';

		return $align_class;
	}
}

if ( ! function_exists( 'gtg_timeline_get_align_classes' ) ) {
	/**
	 * Function Name: gtg_timeline_get_align_classes description.
	 *
	 * @param array  $attributes attribute array.
	 * @param string $index_val  post index.
	 * @return string            output HTML/String.
	 */
	function gtg_timeline_get_align_classes( $attributes, $index_val ) {

		$align_class = '';
		$layout = ! empty($attributes['layout']) ? $attributes['layout'] : 'center';
		if ( 'left' === $layout ) {
			$align_class = 'gutengeek-timeline-item-inner gutengeek-timeline-left';
		} elseif ( 'right' === $layout ) {
			$align_class = 'gutengeek-timeline-item-inner gutengeek-timeline-right';
		} elseif ( 'center' == $layout ) {
			if ( 0 === $index_val % 2 ) {
				$align_class = 'gutengeek-timeline-item-inner gutengeek-timeline-right';
			} else {
				$align_class = 'gutengeek-timeline-item-inner gutengeek-timeline-left';
			}
		}

		return $align_class;
	}
}

if ( ! function_exists( 'gtg_timeline_get_day_align_classes' ) ) {
	/**
	 * Function Name: gtg_timeline_get_day_align_classes description.
	 *
	 * @param array  $attributes attribute array.
	 * @param string $index_val  post index.
	 * @return string            output HTML/String.
	 */
	function gtg_timeline_get_day_align_classes( $attributes, $index_val ) {

		$day_align_class = '';

		$layout = ! empty($attributes['layout']) ? $attributes['layout'] : 'center';
		if ( 'left' === $layout ) {
			$day_align_class = 'gutengeek-timeline-day-new gutengeek-timeline-day-left';
		} elseif ( 'right' === $layout ) {
			$day_align_class = 'gutengeek-timeline-day-new gutengeek-timeline-day-right';
		} elseif ( 'center' === $layout ) {
			if ( 0 === $index_val % 2 ) {
				$day_align_class = 'gutengeek-timeline-day-new gutengeek-timeline-day-right';
			} else {
				$day_align_class = 'gutengeek-timeline-day-new gutengeek-timeline-day-left';
			}
		}

		return $day_align_class;
	}
}


if ( ! function_exists( 'gtg_get_static_css_file_path' ) ) {
	/**
	 * get static css file path
	 *
	 * @param null $post_id
	 * @return mixed|void
	 */
	function gtg_get_static_css_file_path( $post_id = null ) {
		$filename = GTG_AB_STATIC_CSS_PATH . $post_id . '.css';

		return apply_filters( 'gutengeek_post_css_file_path', $filename, $post_id );
	}
}

if ( ! function_exists( 'gtg_get_static_css_file_url' ) ) {
	/**
	 * get static css file url
	 *
	 * @param null $post_id
	 * @return mixed|void
	 */
	function gtg_get_static_css_file_url( $post_id = null ) {
		$file = gtg_get_static_css_file_path( $post_id );
		$url  = '';
		if ( file_exists( $file ) ) {
			$url = GTG_AB_STATIC_CSS_URL . $post_id . '.css';
		}

		return apply_filters( 'gutengeek_post_css_file_url', $url, $post_id );
	}
}

if ( ! function_exists( 'gtg_shape_backgrounds' ) ) {
	function gtg_shape_backgrounds() {
		return apply_filters( 'gutengeek_shape_backgrounds', [
			'mask-01'          => '<svg version="1.1" id="Layer_1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" x="0px" y="0px"
	 viewBox="0 0 1920 470" style="enable-background:new 0 0 1920 470;" xml:space="preserve">
<path d="M0,0h1920v310L0,470V0z"/>
</svg>',
			'mask-01-b'          => '<svg xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" version="1.1" id="Layer_1" x="0px" y="0px" viewBox="0 0 1920 160" style="enable-background:new 0 0 1920 160;" xml:space="preserve">
<g style="transform: rotate3d(-180, 0, 0, -180deg); transform-origin: center"><polygon points="1920,160 1920,0 0,160 "/></g>
</svg>',
			'mask-02'          => '<svg version="1.1" id="Layer_1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" x="0px" y="0px"
	 viewBox="0 0 1920 424" style="enable-background:new 0 0 1920 424;" xml:space="preserve">
<path d="M0,0v424c0,0,373-47,674-47s503,42,762,42s484-50,484-50V0H0z"/>
</svg>',
			'mask-02-b'          => '<svg version="1.1" id="Layer_1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" x="0px" y="0px"
	 viewBox="0 0 1920 55" style="enable-background:new 0 0 1920 55;" xml:space="preserve">
<style type="text/css">
	.st0{fill-rule:evenodd;clip-rule:evenodd;fill:#231F20;}
</style>
<g style="transform: rotate3d(-180, 0, 0, -180deg); transform-origin: center"><path d="M674,8C373,8,0,55,0,55h1920V0c0,0-225,50-484,50S975,8,674,8z"/></g>
</svg>
',
			'mask-03'          => '<svg version="1.1" id="Layer_1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" x="0px" y="0px"
	 viewBox="0 0 1920 405" style="enable-background:new 0 0 1920 405;" xml:space="preserve">
<path d="M1919.78,95C1909.24,42.35,1483.58,0,960,0S10.76,42.35,0.22,95H0v310h1920V95H1919.78z"/>
</svg>',
			'mask-03-b'          => '<svg version="1.1" id="Layer_1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" x="0px" y="0px"
	 viewBox="0 0 1920 95" style="enable-background:new 0 0 1920 95;" xml:space="preserve">
<g>
	<path d="M0,95h0.2C10.8,42.3,436.4,0,960,0H0V95z"/>
	<path d="M960,0c523.6,0,949.2,42.3,959.8,95h0.2V0H960z"/>
</g>
</svg>',
			'mask-04'          => '<svg version="1.1" id="Layer_1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" x="0px" y="0px"
	 viewBox="0 0 1920 405" style="enable-background:new 0 0 1920 405;" xml:space="preserve">
<path d="M1919.78,310c-10.54,52.65-436.2,95-959.78,95S10.76,362.65,0.22,310H0V0h1920v310H1919.78z"/>
</svg>',
			'wave'            => '<svg viewBox="0 0 1280 86" preserveAspectRatio="xMidYMid slice" xmlns="http://www.w3.org/2000/svg"><g><path d="M833.9 27.5c-5.8 3.2-11 7.3-15.5 12.2-7.1-6.9-17.5-8.8-26.6-5-30.6-39.2-87.3-46.1-126.5-15.5-1.4 1.1-2.8 2.2-4.1 3.4C674.4 33.4 684 48 688.8 64.3c4.7.6 9.3 1.8 13.6 3.8 7.8-24.7 34.2-38.3 58.9-30.5 14.4 4.6 25.6 15.7 30.3 30 14.2 1.2 27.7 6.9 38.5 16.2C840.6 49.6 876 29.5 910.8 38c-20.4-20.3-51.8-24.6-76.9-10.5zM384 43.9c-9 5-16.7 11.9-22.7 20.3 15.4-7.8 33.3-8.7 49.4-2.6 3.7-10.1 9.9-19.1 18.1-26-15.4-2.3-31.2.6-44.8 8.3zm560.2 13.6c2 2.2 3.9 4.5 5.7 6.9 5.6-2.6 11.6-4 17.8-4.1-7.6-2.4-15.6-3.3-23.5-2.8zM178.7 7c29-4.2 57.3 10.8 70.3 37 8.9-8.3 20.7-12.8 32.9-12.5C256.4 1.8 214.7-8.1 178.7 7zm146.5 56.3c1.5 4.5 2.4 9.2 2.5 14 .4.2.8.4 1.2.7 3.3 1.9 6.3 4.2 8.9 6.9 5.8-8.7 13.7-15.7 22.9-20.5-11.1-5.2-23.9-5.6-35.5-1.1zM33.5 54.9c21.6-14.4 50.7-8.5 65 13 .1.2.2.3.3.5 7.3-1.2 14.8-.6 21.8 1.6.6-10.3 3.5-20.4 8.6-29.4.3-.6.7-1.2 1.1-1.8-32.1-17.2-71.9-10.6-96.8 16.1zm1228.9 2.7c2.3 2.9 4.4 5.9 6.2 9.1 3.8-.5 7.6-.8 11.4-.8V48.3c-6.4 1.8-12.4 5-17.6 9.3zM1127.3 11c1.9.9 3.7 1.8 5.6 2.8 14.2 7.9 25.8 19.7 33.5 34 13.9-11.4 31.7-16.9 49.6-15.3-20.5-27.7-57.8-36.8-88.7-21.5z" fill-opacity=".5"/><path d="M0 0v66c6.8 0 13.5.9 20.1 2.6 3.5-5.4 8.1-10.1 13.4-13.6 24.9-26.8 64.7-33.4 96.8-16 10.5-17.4 28.2-29.1 48.3-32 36.1-15.1 77.7-5.2 103.2 24.5 19.7.4 37.1 13.1 43.4 31.8 11.5-4.5 24.4-4.2 35.6 1.1l.4-.2c15.4-21.4 41.5-32.4 67.6-28.6 25-21 62.1-18.8 84.4 5.1 6.7-6.6 16.7-8.4 25.4-4.8 29.2-37.4 83.3-44.1 120.7-14.8l1.8 1.5c37.3-32.9 94.3-29.3 127.2 8 1.2 1.3 2.3 2.7 3.4 4.1 9.1-3.8 19.5-1.9 26.6 5 24.3-26 65-27.3 91-3.1.5.5 1 .9 1.5 1.4 12.8 3.1 24.4 9.9 33.4 19.5 7.9-.5 15.9.4 23.5 2.8 7-.1 13.9 1.5 20.1 4.7 3.9-11.6 15.5-18.9 27.7-17.5.2-.3.3-.6.5-.9 22.1-39.2 70.7-54.7 111.4-35.6 30.8-15.3 68.2-6.2 88.6 21.5 18.3 1.7 35 10.8 46.5 25.1 5.2-4.3 11.1-7.4 17.6-9.3V0H0z"/></g></svg>',
			'wave-opacity'    => '<svg viewBox="0 0 1280 140" preserveAspectRatio="none" xmlns="http://www.w3.org/2000/svg"><g><path d="M0 51.76c36.21-2.25 77.57-3.58 126.42-3.58 320 0 320 57 640 57 271.15 0 312.58-40.91 513.58-53.4V0H0z" fill-opacity=".3"/><path d="M0 24.31c43.46-5.69 94.56-9.25 158.42-9.25 320 0 320 89.24 640 89.24 256.13 0 307.28-57.16 481.58-80V0H0z" fill-opacity=".5"/><path d="M0 0v3.4C28.2 1.6 59.4.59 94.42.59c320 0 320 84.3 640 84.3 285 0 316.17-66.85 545.58-81.49V0z"/></g></svg>',
			'3-waves-opacity' => '<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 1000 84.94">
				<path d="M0,0V72.94c14.46,5.89,32.38,10.5,54.52.26,110.25-51,120.51,23.71,192.6-4.3,144.73-56.23,154.37,49.44,246.71,4.64C637,4.05,622.19,124.16,757.29,66.21c93-39.91,108.38,54.92,242.71-8.25V0Z"  fill-rule="evenodd" fill-opacity=".3"/>
				<path d="M0,0V52.83c131.11,59.9,147-32.91,239.24,6.65,135.09,58,120.24-62.16,263.46,7.34,92.33,44.8,102-60.88,246.71-4.64,72.1,28,82.35-46.71,192.6,4.3,23.95,11.08,43,4.78,58-1.72V0Z" fill-opacity=".3" fill-rule="evenodd"/>
				<path d="M0,0V24.26c15.6,6.95,35.77,15.41,61.78,3.38,110.25-51,120.51,23.71,192.6-4.3C399.11-32.89,408.75,72.79,501.08,28,644.3-41.51,629.45,78.6,764.54,20.65,855.87-18.53,872.34,72.12,1000,15.7V0Z" fill-rule="evenodd"/>
			</svg>',
			'slice'           => '<svg viewBox="0 0 1280 140" preserveAspectRatio="none" xmlns="http://www.w3.org/2000/svg"><g><path d="M0 0v60s573.09 80 1280 80V0z" fill-opacity=".3"/><path d="M0 0v30s573.09 110 1280 110V0z" fill-opacity=".5"/><path d="M0 0s573.09 140 1280 140V0z"/></g></svg>',
			'slice-opacity'   => '<svg viewBox="0 0 1280 140" preserveAspectRatio="none" xmlns="http://www.w3.org/2000/svg"><g ><path d="M1280 140V0H0l1280 140z" fill-opacity=".5"/><path d="M1280 98V0H0l1280 98z"/></g></svg>',
			'clouds'          => '<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 283.5 27.8" preserveAspectRatio="xMidYMax slice">
				<path d="M0 0v6.7c1.9-.8 4.7-1.4 8.5-1 9.5 1.1 11.1 6 11.1 6s2.1-.7 4.3-.2c2.1.5 2.8 2.6 2.8 2.6s.2-.5 1.4-.7c1.2-.2 1.7.2 1.7.2s0-2.1 1.9-2.8c1.9-.7 3.6.7 3.6.7s.7-2.9 3.1-4.1 4.7 0 4.7 0 1.2-.5 2.4 0 1.7 1.4 1.7 1.4h1.4c.7 0 1.2.7 1.2.7s.8-1.8 4-2.2c3.5-.4 5.3 2.4 6.2 4.4.4-.4 1-.7 1.8-.9 2.8-.7 4 .7 4 .7s1.7-5 11.1-6c9.5-1.1 12.3 3.9 12.3 3.9s1.2-4.8 5.7-5.7c4.5-.9 6.8 1.8 6.8 1.8s.6-.6 1.5-.9c.9-.2 1.9-.2 1.9-.2s5.2-6.4 12.6-3.3c7.3 3.1 4.7 9 4.7 9s1.9-.9 4 0 2.8 2.4 2.8 2.4 1.9-1.2 4.5-1.2 4.3 1.2 4.3 1.2.2-1 1.4-1.7 2.1-.7 2.1-.7-.5-3.1 2.1-5.5 5.7-1.4 5.7-1.4 1.5-2.3 4.2-1.1c2.7 1.2 1.7 5.2 1.7 5.2s.3-.1 1.3.5c.5.4.8.8.9 1.1.5-1.4 2.4-5.8 8.4-4 7.1 2.1 3.5 8.9 3.5 8.9s.8-.4 2 0 1.1 1.1 1.1 1.1 1.1-1.1 2.3-1.1 2.1.5 2.1.5 1.9-3.6 6.2-1.2 1.9 6.4 1.9 6.4 2.6-2.4 7.4 0c3.4 1.7 3.9 4.9 3.9 4.9s3.3-6.9 10.4-7.9 11.5 2.6 11.5 2.6.8 0 1.2.2c.4.2.9.9.9.9s4.4-3.1 8.3.2c1.9 1.7 1.5 5 1.5 5s.3-1.1 1.6-1.4c1.3-.3 2.3.2 2.3.2s-.1-1.2.5-1.9 1.9-.9 1.9-.9-4.7-9.3 4.4-13.4c5.6-2.5 9.2.9 9.2.9s5-6.2 15.9-6.2 16.1 8.1 16.1 8.1.7-.2 1.6-.4V0H0z"></path>
			</svg>',
			'clouds-flat'     => '<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 1000 86.44">
				<path d="M1000,0H0V68.64A50,50,0,0,0,85.38,48.81v-.09a25.19,25.19,0,0,0,20.89-4.31,32.85,32.85,0,0,0,40.49,2.38c9.39-1.53,16.67-8.4,17.67-17a14.89,14.89,0,0,0,1.74.57,14.7,14.7,0,0,0,11.15,3.1c4.17,5.14,11.51,7.83,19.11,6.32a20.31,20.31,0,0,0,13.62-9.33A20.31,20.31,0,0,0,219,32.56a13.49,13.49,0,0,0,24.86,7.25,13.43,13.43,0,0,0,10-1.91c2.66,8.32,12.06,13.37,21.9,11.42a19.93,19.93,0,0,0,14.75-11.58,24.3,24.3,0,0,0,13,.92,23.88,23.88,0,0,0,14-8.3A13.46,13.46,0,0,0,334,32.69a25.39,25.39,0,0,0,7.23.41,30.38,30.38,0,0,0,6-1.2c.2.4.4.9.6,1.3a20.81,20.81,0,0,0,14.6,11c10.2,2.2,20-2.9,22.9-11.5a13.84,13.84,0,0,0,10.3,2.1,14,14,0,0,0,19.25,4.63l.05,0a14.17,14.17,0,0,0,6.7-11.8,20,20,0,0,0,9.3-2,21.31,21.31,0,0,0,14,9.9c10.6,2.3,20.9-3.4,23.2-12.7a28.46,28.46,0,0,0,37.2,7.1A23.53,23.53,0,0,0,510,26l.24,0a8.91,8.91,0,0,0,2.07-.72A15.07,15.07,0,0,0,528,35.9a17.66,17.66,0,0,0,33.65-4.66,26.65,26.65,0,0,0,5.65,3.46,28.5,28.5,0,0,0,7,2.2,29.16,29.16,0,0,0,15.2-1.3c2.8,6.6,9.3,11.8,17.5,13.3,11.4,2.1,22.2-3.8,25.3-13.4,0-.1.1-.2.1-.4.3.2.7.4,1,.6a15.93,15.93,0,0,0,10.7,1.5,15.75,15.75,0,0,0,26.69-.66A10.85,10.85,0,0,0,686.86,35a10.82,10.82,0,0,0,7-.48q.7.31,1.41.58c2.16,6.21,9.11,10.24,16.67,9.28a16,16,0,0,0,12.48-8.49,19.56,19.56,0,0,0,10.37,1.45,19.23,19.23,0,0,0,9.36-3.78,21.69,21.69,0,0,0,2.93,0,13.67,13.67,0,0,0,1.63-.16,10.84,10.84,0,0,0,15.13-2.91,10.8,10.8,0,0,0,7.32,2.19,24.79,24.79,0,0,0,3.52,1.48,25.09,25.09,0,0,0,8.1,1.4h.65A18.51,18.51,0,0,0,795.9,38.2,18.82,18.82,0,0,0,809.34,30c2.67,10,12.75,17.44,24.8,17.44,9.38,0,17.57-4.5,22-11.2a32,32,0,0,0,14,4.4,46.9,46.9,0,0,0,46.1,17.89A55,55,0,0,0,1000,73.07V0Z" transform="translate(0 0)"/>
			</svg>',
			'clouds-opacity'  => '<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 1000 86.47"><g fill-opacity=".3"><path d="M823,15.52l.24-.07A27.72,27.72,0,0,0,864.3,30.53a46.9,46.9,0,0,0,51.9,28A55,55,0,0,0,1000,73.07V0H792C795.79,12,809.32,18.85,823,15.52Z"/><path d="M23.71,83.4A50,50,0,0,0,85.39,48.77v-.05a25.19,25.19,0,0,0,20.89-4.31,32.67,32.67,0,0,0,12.82,7A32.88,32.88,0,0,0,154.31,0H0V68.64A49.74,49.74,0,0,0,23.71,83.4Z"/></g><g fill-opacity=".4"><path d="M499.63,19.13h.08a8.91,8.91,0,0,0,12.64,6.15A15.07,15.07,0,0,0,528,35.9a17.67,17.67,0,0,0,33.67-9.55v0A8.9,8.9,0,0,0,567.86,22a11.61,11.61,0,0,0,7.48-22H503.08a11.65,11.65,0,0,0-1.71,4.21,9.2,9.2,0,0,0-3.85-.28c-4.65.65-8,4.58-7.37,8.77S495,19.78,499.63,19.13Z"/><path d="M631.55,20.67c1,7.6,8.68,12.87,17.22,11.78a16.35,16.35,0,0,0,11.45-6.74,16.34,16.34,0,0,0,7.07,2.14A10.86,10.86,0,0,0,686.86,35a10.82,10.82,0,0,0,8.1-1c1.68,6.83,9,11.4,17,10.38a16,16,0,0,0,12.48-8.49,19.56,19.56,0,0,0,10.37,1.45,19.24,19.24,0,0,0,11.72-5.89,10.85,10.85,0,0,0,17.33-.92A10.81,10.81,0,0,0,776,31.2a17.64,17.64,0,0,0,3.38,1,18.52,18.52,0,0,0,16.52,6A18.82,18.82,0,0,0,809.34,30c2.67,10,12.75,17.44,24.8,17.44,9.38,0,17.57-4.5,22-11.2a32,32,0,0,0,16.53,4.5,31.47,31.47,0,0,0,20.23-7.14,17.75,17.75,0,0,0,28.32,2.09,17.74,17.74,0,0,0,22.71,1.75c4.13,10.05,15,17.22,27.72,17.22,13.43,0,24.75-8,28.33-18.88V0H599.32C607.84,23.13,631.55,20.67,631.55,20.67Z"/><path d="M.74,30.73c0,12.33,11.21,22.33,25.08,22.36,10.84,0,20.08-6.07,23.61-14.62A15.09,15.09,0,0,0,68.74,37a15.1,15.1,0,0,0,24.1-1.74,26.76,26.76,0,0,0,17.2,6.1,27.24,27.24,0,0,0,14.07-3.81,22.33,22.33,0,0,0,18.71,9.56c11.24,0,20.49-7.56,21.62-17.28a14.92,14.92,0,0,0,10.72.18c3.29,7.35,12.1,11.63,21.28,9.81a20.31,20.31,0,0,0,13.62-9.33A20.31,20.31,0,0,0,219,32.56a13.49,13.49,0,0,0,24.86,7.25,13.43,13.43,0,0,0,10-1.91c2.66,8.32,12.06,13.37,21.9,11.42a19.93,19.93,0,0,0,14.75-11.58,24.3,24.3,0,0,0,13,.92,23.88,23.88,0,0,0,14-8.3,13.47,13.47,0,0,0,21.4-2.61,13.46,13.46,0,0,0,17.17-2c4.56,6.88,13.69,10.63,23.18,8.76,12.14-2.4,20.26-13.09,18.13-23.88A73.93,73.93,0,0,0,400.48,0H0V29.49C.24,29.91.48,30.32.74,30.73Z"/></g><path d="M16.3,13.9c10.2,2.5,20.3-1.1,25.5-8.3a14.66,14.66,0,0,0,18.5,3A14.6,14.6,0,0,0,80,14.9a13.14,13.14,0,0,0,3.4-2.4,25.71,25.71,0,0,0,14.8,9.7,26,26,0,0,0,14.1-.4,21.75,21.75,0,0,0,15.4,13.3c10.6,2.6,21-2.4,24.3-11.3a15,15,0,0,0,10.7,2.6,17.69,17.69,0,0,0,1.6,2.2,14.69,14.69,0,0,0,17.6,3.5,7.46,7.46,0,0,0,1.2-.7,14.54,14.54,0,0,0,6.4-8.9,12.61,12.61,0,0,0,.4-2.8,20.63,20.63,0,0,0,9.8-1.8,11.35,11.35,0,0,0,1.5,2.3A22.35,22.35,0,0,0,214,28.6c11.2,2.8,22.4-3.1,24.8-13.1a24.63,24.63,0,0,0,16.3,11.6c9.8,2.1,19.4-1.7,24.2-8.7a14,14,0,0,0,17.8,2.4,14.07,14.07,0,0,0,19.1,5.4,12.25,12.25,0,0,0,3.1-2.4,22.5,22.5,0,0,0,5.8,5.3,25.42,25.42,0,0,0,16.1,4,30.38,30.38,0,0,0,6-1.2c.2.4.4.9.6,1.3a20.81,20.81,0,0,0,14.6,11c10.2,2.2,20-2.9,22.9-11.5a13.84,13.84,0,0,0,10.3,2.1,14,14,0,0,0,19.3,4.6,14.17,14.17,0,0,0,6.7-11.8,20,20,0,0,0,9.3-2,21.31,21.31,0,0,0,14,9.9c10.6,2.3,20.9-3.4,23.2-12.7a28.46,28.46,0,0,0,37.2,7.1,23.54,23.54,0,0,0,7.3-7.1,15.79,15.79,0,0,0,20.1,2.1,15.69,15.69,0,0,0,21.6,5.5,13.88,13.88,0,0,0,3.5-2.9,26.66,26.66,0,0,0,9.5,7.2,28.5,28.5,0,0,0,7,2.2,29.16,29.16,0,0,0,15.2-1.3c2.8,6.6,9.3,11.8,17.5,13.3,11.4,2.1,22.2-3.8,25.3-13.4,0-.1.1-.2.1-.4.3.2.7.4,1,.6a15.93,15.93,0,0,0,10.7,1.5,15.79,15.79,0,0,0,28.7-6c.1-.4.1-.8.2-1.2a10.87,10.87,0,0,0,.1-1.8,22.26,22.26,0,0,0,10.4-2.6,25,25,0,0,0,3.9,4.7,24.65,24.65,0,0,0,12.2,6A24.5,24.5,0,0,0,715.3,34a19.09,19.09,0,0,0,10.2-13.4h.5a21.68,21.68,0,0,0,21.1,13,13.67,13.67,0,0,0,1.9-.2,22.1,22.1,0,0,0,13.8-7.7,24.79,24.79,0,0,0,11.9,8.5,25.09,25.09,0,0,0,8.1,1.4,25.86,25.86,0,0,0,18.5-6.7,21.77,21.77,0,0,0,5.2-7.2,15,15,0,0,0,19.1-1,15,15,0,0,0,21,2,13.81,13.81,0,0,0,2.8-3.1A26.84,26.84,0,0,0,866.3,26a27.39,27.39,0,0,0,14-3.4,22.36,22.36,0,0,0,18.3,9.9c11.1.3,20.4-7,21.8-16.6a15,15,0,0,0,11.2.2,15,15,0,0,0,21.1,1,15.16,15.16,0,0,0,4.7-13.5A22.32,22.32,0,0,0,966.3,0H0V1.6A25.29,25.29,0,0,0,16.3,13.9Z"/><path d="M983.6,7.3A22.61,22.61,0,0,0,1000,1.1V0H967.3A22.52,22.52,0,0,0,983.6,7.3Z"/></svg>',
			'drip'            => '<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 1000 91.01">
				<path d="M211,21a429.73,429.73,0,0,1,94-2c75.81,6.66,94.56,25.51,100,32,15.2,18.14,17.38,40.68,26,40,9.18-.72,7.66-26.36,28-39,13.08-8.13,27.68-6.19,29-6,19.5,2.86,22.53,18.4,36,18,15.47-.46,16-21.09,35-27,18.63-5.79,28.46,10.82,56,11,17.76.11,27.66-6.7,43-13,1.67-.68,27.3-8.31,56-14.49,0,0,25.6-5.52,58-9.51,41.3-5.08,122.78-9.93,228-11H0C96.11,27.3,165,26.91,211,21Z"/>
			</svg>',
			'wave-hill'       => '<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 1047.1 3.7" preserveAspectRatio="xMidYMin slice">
				<path d="M1047.1,0C557,0,8.9,0,0,0v1.6c0,0,0.6-1.5,2.7-0.3C3.9,2,6.1,4.1,8.3,3.5c0.9-0.2,1.5-1.9,1.5-1.9 s0.6-1.5,2.7-0.3C13.8,2,16,4.1,18.2,3.5c0.9-0.2,1.5-1.9,1.5-1.9s0.6-1.5,2.7-0.3C23.6,2,25.9,4.1,28,3.5c0.9-0.2,1.5-1.9,1.5-1.9 c0,0,0.6-1.5,2.7-0.3c1.2,0.7,3.5,2.8,5.6,2.2c0.9-0.2,1.5-1.9,1.5-1.9c0,0,0.6-1.5,2.7-0.3c1.2,0.7,3.5,2.8,5.6,2.2 c0.9-0.2,1.5-1.9,1.5-1.9s0.6-1.5,2.7-0.3c1.2,0.7,3.5,2.8,5.6,2.2c0.9-0.2,1.5-1.9,1.5-1.9s0.6-1.5,2.7-0.3C63,2,65.3,4.1,67.4,3.5 C68.3,3.3,69,1.6,69,1.6s0.6-1.5,2.7-0.3c1.2,0.7,3.5,2.8,5.6,2.2c0.9-0.2,1.5-1.9,1.5-1.9c0,0,0.6-1.5,2.7-0.3 C82.7,2,85,4.1,87.1,3.5c0.9-0.2,1.5-1.9,1.5-1.9s0.6-1.5,2.7-0.3C92.6,2,94.8,4.1,97,3.5c0.9-0.2,1.5-1.9,1.5-1.9s0.6-1.5,2.7-0.3 c1.2,0.7,3.5,2.8,5.6,2.2c0.9-0.2,1.5-1.9,1.5-1.9s0.6-1.5,2.7-0.3c1.2,0.7,3.5,2.8,5.6,2.2c0.9-0.2,1.5-1.9,1.5-1.9 c0,0,0.6-1.5,2.7-0.3c1.2,0.7,3.5,2.8,5.6,2.2c0.9-0.2,1.5-1.9,1.5-1.9c0,0,0.6-1.5,2.7-0.3c1.2,0.7,3.5,2.8,5.6,2.2 c0.9-0.2,1.5-1.9,1.5-1.9s0.6-1.5,2.7-0.3c1.2,0.7,3.5,2.8,5.6,2.2c0.9-0.2,1.5-1.9,1.5-1.9s0.6-1.5,2.7-0.3 c1.2,0.7,3.5,2.8,5.6,2.2c0.9-0.2,1.5-1.9,1.5-1.9s0.6-1.5,2.7-0.3c1.2,0.7,3.5,2.8,5.6,2.2c0.9-0.2,1.5-1.9,1.5-1.9 c0,0,0.6-1.5,2.7-0.3c1.2,0.7,3.5,2.8,5.6,2.2c0.9-0.2,1.5-1.9,1.5-1.9s0.6-1.5,2.7-0.3c1.2,0.7,3.5,2.8,5.6,2.2 c0.9-0.2,1.5-1.9,1.5-1.9s0.6-1.5,2.7-0.3c1.2,0.7,3.5,2.8,5.6,2.2c0.9-0.2,1.5-1.9,1.5-1.9s0.6-1.5,2.7-0.3 c1.2,0.7,3.5,2.8,5.6,2.2c0.9-0.2,1.5-1.9,1.5-1.9c0,0,0.6-1.5,2.7-0.3c1.2,0.7,3.5,2.8,5.6,2.2c0.9-0.2,1.5-1.9,1.5-1.9 c0,0,0.6-1.5,2.7-0.3c1.2,0.7,3.5,2.8,5.6,2.2c0.9-0.2,1.5-1.9,1.5-1.9s0.6-1.5,2.7-0.3c1.2,0.7,3.5,2.8,5.6,2.2 c0.9-0.2,1.5-1.9,1.5-1.9s0.6-1.5,2.7-0.3c1.2,0.7,3.5,2.8,5.6,2.2c0.9-0.2,1.5-1.9,1.5-1.9s0.6-1.5,2.7-0.3 c1.2,0.7,3.5,2.8,5.6,2.2c0.9-0.2,1.5-1.9,1.5-1.9c0,0,0.6-1.5,2.7-0.3c1.2,0.7,3.5,2.8,5.6,2.2c0.9-0.2,1.5-1.9,1.5-1.9 s0.6-1.5,2.7-0.3c1.2,0.7,3.5,2.8,5.6,2.2c0.9-0.2,1.5-1.9,1.5-1.9s0.6-1.5,2.7-0.3c1.2,0.7,3.5,2.8,5.6,2.2 c0.9-0.2,1.5-1.9,1.5-1.9s0.6-1.5,2.7-0.3c1.2,0.7,3.5,2.8,5.6,2.2c0.9-0.2,1.5-1.9,1.5-1.9c0,0,0.6-1.5,2.7-0.3 c1.2,0.7,3.5,2.8,5.6,2.2c0.9-0.2,1.5-1.9,1.5-1.9c0,0,0.6-1.5,2.7-0.3c1.2,0.7,3.5,2.8,5.6,2.2c0.9-0.2,1.5-1.9,1.5-1.9 s0.6-1.5,2.7-0.3c1.2,0.7,3.5,2.8,5.6,2.2c0.9-0.2,1.5-1.9,1.5-1.9s0.6-1.5,2.7-0.3c1.2,0.7,3.5,2.8,5.6,2.2 c0.9-0.2,1.5-1.9,1.5-1.9s0.6-1.5,2.7-0.3c1.2,0.7,3.5,2.8,5.6,2.2c0.9-0.2,1.5-1.9,1.5-1.9c0,0,0.6-1.5,2.7-0.3 c1.2,0.7,3.5,2.8,5.6,2.2c0.9-0.2,1.5-1.9,1.5-1.9s0.6-1.5,2.7-0.3c1.2,0.7,3.5,2.8,5.6,2.2c0.9-0.2,1.5-1.9,1.5-1.9 s0.6-1.5,2.7-0.3c1.2,0.7,3.5,2.8,5.6,2.2c0.9-0.2,1.5-1.9,1.5-1.9s0.6-1.5,2.7-0.3c1.2,0.7,3.5,2.8,5.6,2.2 c0.9-0.2,1.5-1.9,1.5-1.9c0,0,0.6-1.5,2.7-0.3c1.2,0.7,3.5,2.8,5.6,2.2c0.9-0.2,1.5-1.9,1.5-1.9c0,0,0.6-1.5,2.7-0.3 c1.2,0.7,3.5,2.8,5.6,2.2c0.9-0.2,1.5-1.9,1.5-1.9s0.6-1.5,2.7-0.3c1.2,0.7,3.5,2.8,5.6,2.2c0.9-0.2,1.5-1.9,1.5-1.9 s0.6-1.5,2.7-0.3c1.2,0.7,3.5,2.8,5.6,2.2c0.9-0.2,1.5-1.9,1.5-1.9s0.6-1.5,2.7-0.3c1.2,0.7,3.5,2.8,5.6,2.2 c0.9-0.2,1.5-1.9,1.5-1.9c0,0,0.6-1.5,2.7-0.3c1.2,0.7,3.5,2.8,5.6,2.2c0.9-0.2,1.5-1.9,1.5-1.9s0.6-1.5,2.7-0.3 c1.2,0.7,3.5,2.8,5.6,2.2c0.9-0.2,1.5-1.9,1.5-1.9s0.6-1.5,2.7-0.3c1.2,0.7,3.5,2.8,5.6,2.2c0.9-0.2,1.5-1.9,1.5-1.9 s0.6-1.5,2.7-0.3c1.2,0.7,3.5,2.8,5.6,2.2c0.9-0.2,1.5-1.9,1.5-1.9c0,0,0.6-1.5,2.7-0.3c1.2,0.7,3.5,2.8,5.6,2.2 c0.9-0.2,1.5-1.9,1.5-1.9c0,0,0.6-1.5,2.7-0.3c1.2,0.7,3.5,2.8,5.6,2.2c0.9-0.2,1.5-1.9,1.5-1.9s0.6-1.5,2.7-0.3 c1.2,0.7,3.5,2.8,5.6,2.2c0.9-0.2,1.5-1.9,1.5-1.9s0.6-1.5,2.7-0.3c1.2,0.7,3.5,2.8,5.6,2.2c0.9-0.2,1.5-1.9,1.5-1.9 s0.6-1.5,2.7-0.3c1.2,0.7,3.5,2.8,5.6,2.2c0.9-0.2,1.5-1.9,1.5-1.9c0,0,0.6-1.5,2.7-0.3c1.2,0.7,3.5,2.8,5.6,2.2 c0.9-0.2,1.5-1.9,1.5-1.9s0.6-1.5,2.7-0.3c1.2,0.7,3.5,2.8,5.6,2.2c0.9-0.2,1.5-1.9,1.5-1.9s0.6-1.5,2.7-0.3 c1.2,0.7,3.5,2.8,5.6,2.2c0.9-0.2,1.5-1.9,1.5-1.9s0.6-1.5,2.7-0.3c1.2,0.7,3.5,2.8,5.6,2.2c0.9-0.2,1.5-1.9,1.5-1.9 c0,0,0.6-1.5,2.7-0.3c1.2,0.7,3.5,2.8,5.6,2.2c0.9-0.2,1.5-1.9,1.5-1.9c0,0,0.6-1.5,2.7-0.3c1.2,0.7,3.5,2.8,5.6,2.2 c0.9-0.2,1.5-1.9,1.5-1.9s0.6-1.5,2.7-0.3c1.2,0.7,3.5,2.8,5.6,2.2c0.9-0.2,1.5-1.9,1.5-1.9s0.6-1.5,2.7-0.3 c1.2,0.7,3.5,2.8,5.6,2.2c0.9-0.2,1.5-1.9,1.5-1.9s0.6-1.5,2.7-0.3c1.2,0.7,3.5,2.8,5.6,2.2c0.9-0.2,1.5-1.9,1.5-1.9 c0,0,0.6-1.5,2.7-0.3c1.2,0.7,3.5,2.8,5.6,2.2c0.9-0.2,1.5-1.9,1.5-1.9s0.6-1.5,2.7-0.3c1.2,0.7,3.5,2.8,5.6,2.2 c0.9-0.2,1.5-1.9,1.5-1.9s0.6-1.5,2.7-0.3c1.2,0.7,3.5,2.8,5.6,2.2c0.9-0.2,1.5-1.9,1.5-1.9s0.6-1.5,2.7-0.3 c1.2,0.7,3.5,2.8,5.6,2.2c0.9-0.2,1.5-1.9,1.5-1.9c0,0,0.6-1.5,2.7-0.3c1.2,0.7,3.5,2.8,5.6,2.2c0.9-0.2,1.5-1.9,1.5-1.9 c0,0,0.6-1.5,2.7-0.3c1.2,0.7,3.5,2.8,5.6,2.2c0.9-0.2,1.5-1.9,1.5-1.9s0.6-1.5,2.7-0.3c1.2,0.7,3.5,2.8,5.6,2.2 c0.9-0.2,1.5-1.9,1.5-1.9s0.6-1.5,2.7-0.3c1.2,0.7,3.5,2.8,5.6,2.2c0.9-0.2,1.5-1.9,1.5-1.9s0.6-1.5,2.7-0.3 c1.2,0.7,3.5,2.8,5.6,2.2c0.9-0.2,1.5-1.9,1.5-1.9c0,0,0.6-1.5,2.7-0.3c1.2,0.7,3.5,2.8,5.6,2.2c0.9-0.2,1.5-1.9,1.5-1.9 s0.6-1.5,2.7-0.3c1.2,0.7,3.5,2.8,5.6,2.2c0.9-0.2,1.5-1.9,1.5-1.9s0.6-1.5,2.7-0.3c1.2,0.7,3.5,2.8,5.6,2.2 c0.9-0.2,1.5-1.9,1.5-1.9s0.6-1.5,2.7-0.3c1.2,0.7,3.5,2.8,5.6,2.2c0.9-0.2,1.5-1.9,1.5-1.9c0,0,0.6-1.5,2.7-0.3 c1.2,0.7,3.5,2.8,5.6,2.2c0.9-0.2,1.5-1.9,1.5-1.9c0,0,0.6-1.5,2.7-0.3c1.2,0.7,3.5,2.8,5.6,2.2c0.9-0.2,1.5-1.9,1.5-1.9 s0.6-1.5,2.7-0.3c1.2,0.7,3.5,2.8,5.6,2.2c0.9-0.2,1.5-1.9,1.5-1.9s0.6-1.5,2.7-0.3c1.2,0.7,3.5,2.8,5.6,2.2 c0.9-0.2,1.5-1.9,1.5-1.9s0.6-1.5,2.7-0.3c1.2,0.7,3.5,2.8,5.6,2.2c0.9-0.2,1.5-1.9,1.5-1.9c0,0,0.6-1.5,2.7-0.3 c1.2,0.7,3.5,2.8,5.6,2.2c0.9-0.2,1.5-1.9,1.5-1.9s0.6-1.5,2.7-0.3c1.2,0.7,3.5,2.8,5.6,2.2c0.9-0.2,1.5-1.9,1.5-1.9 s0.6-1.5,2.7-0.3c1.2,0.7,3.5,2.8,5.6,2.2c0.9-0.2,1.5-1.9,1.5-1.9s0.6-1.5,2.7-0.3c1.2,0.7,3.5,2.8,5.6,2.2 c0.9-0.2,1.5-1.9,1.5-1.9c0,0,0.6-1.5,2.7-0.3c1.2,0.7,3.5,2.8,5.6,2.2c0.9-0.2,1.5-1.9,1.5-1.9c0,0,0.6-1.5,2.7-0.3 c1.2,0.7,3.5,2.8,5.6,2.2c0.9-0.2,1.5-1.9,1.5-1.9s0.6-1.5,2.7-0.3c1.2,0.7,3.5,2.8,5.6,2.2c0.9-0.2,1.5-1.9,1.5-1.9 s0.6-1.5,2.7-0.3c1.2,0.7,3.5,2.8,5.6,2.2c0.9-0.2,1.5-1.9,1.5-1.9s0.6-1.5,2.7-0.3c1.2,0.7,3.5,2.8,5.6,2.2 c0.9-0.2,1.5-1.9,1.5-1.9c0,0,0.6-1.5,2.7-0.3c1.2,0.7,3.5,2.8,5.6,2.2c0.9-0.2,1.5-1.9,1.5-1.9s0.6-1.5,2.7-0.3 c1.2,0.7,3.5,2.8,5.6,2.2c0.9-0.2,1.5-1.9,1.5-1.9s0.6-1.5,2.7-0.3c1.2,0.7,3.5,2.8,5.6,2.2c0.9-0.2,1.5-1.9,1.5-1.9 s0.6-1.5,2.7-0.3c1.2,0.7,3.5,2.8,5.6,2.2c0.9-0.2,1.5-1.9,1.5-1.9c0,0,0.6-1.5,2.7-0.3c1.2,0.7,3.5,2.8,5.6,2.2 c0.9-0.2,1.5-1.9,1.5-1.9c0,0,0.6-1.5,2.7-0.3c1.2,0.7,3.5,2.8,5.6,2.2c0.9-0.2,1.5-1.9,1.5-1.9s0.6-1.5,2.7-0.3 c1.2,0.7,3.5,2.8,5.6,2.2c0.9-0.2,1.5-1.9,1.5-1.9s0.6-1.5,2.7-0.3c1.2,0.7,3.5,2.8,5.6,2.2c0.9-0.2,1.5-1.9,1.5-1.9 s0.6-1.5,2.7-0.3c1.2,0.7,3.5,2.8,5.6,2.2c0.9-0.2,1.5-1.9,1.5-1.9c0,0,0.6-1.5,2.7-0.3c1.2,0.7,3.5,2.8,5.6,2.2 c0.9-0.2,1.5-1.9,1.5-1.9s0.6-1.5,2.7-0.3c1.2,0.7,3.5,2.8,5.6,2.2c0.9-0.2,1.5-1.9,1.5-1.9s0.6-1.5,2.7-0.3 c1.2,0.7,3.5,2.8,5.6,2.2c0.9-0.2,1.5-1.9,1.5-1.9s0.6-1.5,2.7-0.3c1.2,0.7,3.5,2.8,5.6,2.2c0.9-0.2,1.5-1.9,1.5-1.9 c0,0,0.6-1.5,2.7-0.3c1.2,0.7,3.5,2.8,5.6,2.2c0.9-0.2,1.5-1.9,1.5-1.9c0,0,0.6-1.5,2.7-0.3c1.2,0.7,3.5,2.8,5.6,2.2 c0.9-0.2,1.5-1.9,1.5-1.9s0.6-1.5,2.7-0.3c1.2,0.7,3.5,2.8,5.6,2.2c0.9-0.2,1.5-1.9,1.5-1.9s0.6-1.5,2.7-0.3 c1.2,0.7,3.5,2.8,5.6,2.2c0.9-0.2,1.5-1.9,1.5-1.9s0.6-1.5,2.6-0.4V0z M2.5,1.2C2.5,1.2,2.5,1.2,2.5,1.2C2.5,1.2,2.5,1.2,2.5,1.2z M2.7,1.4c0.1,0,0.1,0.1,0.1,0.1C2.8,1.4,2.8,1.4,2.7,1.4z"></path>
			</svg>',
			'hill'            => '<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 1000 100">
				<path d="M499.9,51"/>
				<path d="M0,1v94.2c256.7-171,917.3-15.6,1000,4.8V1H0z"/>
				<path d="M0,100h1.3C273.1-106.1,1000,77.4,1000,77.4V0H0V100z"/>
			</svg>',
			'line-wave'       => '<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 1000 100">
				<path d="M0,0v25.8c4.2,1.1,8.1,4.1,11,9.1c6.3,10.8,19,10.8,25.3,0c7.4-12.8,21.9-12.8,29.3,0c6.3,10.8,19,10.8,25.3,0
					c7.4-12.8,21.9-12.8,29.3,0c6.3,10.8,19,10.8,25.3,0c7.4-12.8,21.9-12.8,29.3,0c6.3,10.8,19,10.8,25.3,0c3.7-6.4,9.2-9.6,14.6-9.6
					c5.5,0,10.9,3.2,14.6,9.6c6.3,10.8,19,10.8,25.3,0c7.4-12.8,21.9-12.8,29.3,0c6.3,10.8,19,10.8,25.3,0c7.4-12.8,21.9-12.8,29.3,0
					c6.3,10.8,19,10.8,25.3,0c3.7-6.4,9.2-9.6,14.6-9.6c5.5,0,10.9,3.2,14.6,9.6c6.3,10.8,19,10.8,25.3,0c7.4-12.8,21.9-12.8,29.3,0
					c6.3,10.8,19,10.8,25.3,0c7.5-12.9,22-12.9,29.3,0c6.1,10.9,19,10.8,25.3,0c7.4-12.8,21.9-12.8,29.3,0c6.3,10.8,19,10.8,25.3,0
					c7.4-12.8,21.9-12.8,29.3,0c6.3,10.8,19,10.8,25.3,0c7.4-12.8,21.9-12.8,29.3,0c6.3,10.8,19,10.8,25.3,0c7.4-12.8,21.9-12.8,29.3,0
					c6.3,10.8,19.2,10.9,25.3,0c7.4-13.3,21.9-13.2,29.3,0c6.1,10.9,19,10.8,25.3,0c7.4-12.8,21.9-12.8,29.3,0c6.3,10.8,19,10.8,25.3,0
					c7.4-12.8,21.9-12.8,29.3,0c6.3,10.8,19,10.8,25.3,0c7.4-12.8,21.9-12.8,29.3,0c6.3,10.8,19,10.8,25.3,0c7.4-12.8,21.9-12.8,29.3,0
					c1.9,3.2,4.3,5.5,7,6.8V0H0z"/>
				<path d="M993,40.9c-7.4-12.8-21.9-12.8-29.3,0c-6.3,10.8-19,10.8-25.3,0c-7.4-12.8-21.9-12.8-29.3,0c-6.3,10.8-19,10.8-25.3,0
					c-7.4-12.8-21.9-12.8-29.3,0c-6.3,10.8-19,10.8-25.3,0c-7.4-12.8-21.9-12.8-29.3,0c-6.3,10.8-19,10.8-25.3,0
					c-7.4-12.8-21.9-12.8-29.3,0c-6.3,10.8-19,10.8-25.3,0c-7.4-12.8-21.9-12.8-29.3,0c-6.3,10.8-19,10.8-25.3,0
					c-7.4-12.8-21.9-12.8-29.3,0c-6.3,10.8-19,10.8-25.3,0c-7.4-12.8-21.9-12.8-29.3,0c-6.3,10.8-19,10.8-25.3,0
					c-7.4-12.8-21.9-12.8-29.3,0c-6.3,10.8-19,10.8-25.3,0c-7.4-12.8-21.9-12.8-29.3,0c-6.3,10.8-19,10.8-25.3,0
					c-7.4-12.8-21.9-12.8-29.3,0c-6.3,10.8-19,10.8-25.3,0c-3.7-6.4-9.2-9.6-14.6-9.6c-5.5,0-10.9,3.2-14.6,9.6
					c-6.3,10.8-19,10.8-25.3,0c-7.4-12.8-21.9-12.8-29.3,0c-6.3,10.8-19,10.8-25.3,0c-7.4-12.8-21.9-12.8-29.3,0
					c-6.3,10.8-19,10.8-25.3,0c-3.7-6.4-9.2-9.6-14.6-9.6c-5.5,0-10.9,3.2-14.6,9.6c-6.3,10.8-19,10.8-25.3,0
					c-7.4-12.8-21.9-12.8-29.3,0c-6.3,10.8-19,10.8-25.3,0c-7.4-12.8-21.9-12.8-29.3,0c-6.3,10.8-19,10.8-25.3,0
					c-7.4-12.8-21.9-12.8-29.3,0c-6.3,10.8-19,10.8-25.3,0c-2.9-4.9-6.8-8-11-9.1V38c4.2,1.1,8.1,4.1,11,9.1c6.3,10.8,19,10.8,25.3,0
					c7.4-12.8,21.9-12.8,29.3,0c6.3,10.8,19,10.8,25.3,0c7.4-12.8,21.9-12.8,29.3,0c6.3,10.8,19,10.8,25.3,0c7.4-12.8,21.9-12.8,29.3,0
					c6.3,10.8,19,10.8,25.3,0c3.7-6.4,9.2-9.6,14.6-9.6c5.5,0,10.9,3.2,14.6,9.6c6.3,10.8,19,10.8,25.3,0c7.4-12.8,21.9-12.8,29.3,0
					c6.3,10.8,19,10.8,25.3,0c7.4-12.8,21.9-12.8,29.3,0c6.3,10.8,19,10.8,25.3,0c3.7-6.4,9.2-9.6,14.6-9.6c5.5,0,10.9,3.2,14.6,9.6
					c6.3,10.8,19,10.8,25.3,0c7.4-12.8,21.9-12.8,29.3,0c6.3,10.8,19,10.8,25.3,0c7.4-12.8,21.9-12.8,29.3,0c6.3,10.8,19,10.8,25.3,0
					c7.4-12.8,21.9-12.8,29.3,0c6.3,10.8,19,10.8,25.3,0c7.4-12.8,21.9-12.8,29.3,0c6.3,10.8,19,10.8,25.3,0c7.4-12.8,21.9-12.8,29.3,0
					c6.3,10.8,19,10.8,25.3,0c7.4-12.8,21.9-12.8,29.3,0c6.3,10.8,19,10.8,25.3,0c7.4-12.8,21.9-12.8,29.3,0c6.3,10.8,19,10.8,25.3,0
					c7.4-12.8,21.9-12.8,29.3,0c6.3,10.8,19,10.8,25.3,0c7.4-12.8,21.9-12.8,29.3,0c6.3,10.8,19,10.8,25.3,0c7.4-12.8,21.9-12.8,29.3,0
					c6.3,10.8,19,10.8,25.3,0c7.4-12.8,21.9-12.8,29.3,0c1.9,3.2,4.3,5.5,7,6.8v-6.2C997.3,46.4,994.9,44.1,993,40.9z"/>
				<path d="M991,50.9c-6.3-10.8-19-10.8-25.3,0c-7.4,12.8-21.9,12.8-29.3,0c-6.3-10.8-19-10.8-25.3,0c-7.4,12.8-21.9,12.8-29.3,0
					c-6.3-10.8-19-10.8-25.3,0c-7.4,12.8-21.9,12.8-29.3,0c-6.3-10.8-19-10.8-25.3,0c-7.4,12.8-21.9,12.8-29.3,0
					c-6.3-10.8-19-10.8-25.3,0c-7.4,12.8-21.9,12.8-29.3,0c-6.3-10.8-19-10.8-25.3,0c-7.4,12.8-21.9,12.8-29.3,0
					c-6.3-10.8-19-10.8-25.3,0c-7.4,12.8-21.9,12.8-29.3,0c-6.3-10.8-19-10.8-25.3,0c-7.4,12.8-21.9,12.8-29.3,0
					c-6.3-10.8-19-10.8-25.3,0c-7.4,12.8-21.9,12.8-29.3,0c-6.3-10.8-19-10.8-25.3,0c-7.4,12.8-21.9,12.8-29.3,0
					c-6.3-10.8-19-10.8-25.3,0c-7.4,12.8-21.9,12.8-29.3,0c-6.3-10.8-19-10.8-25.3,0c-7.4,12.8-21.9,12.8-29.3,0
					c-6.3-10.8-19-10.8-25.3,0c-7.4,12.8-21.9,12.8-29.3,0c-6.3-10.8-19-10.8-25.3,0c-7.4,12.8-21.9,12.8-29.3,0
					c-6.3-10.8-19-10.8-25.3,0c-7.4,12.8-21.9,12.8-29.3,0c-6.3-10.8-19-10.8-25.3,0c-7.4,12.8-21.9,12.8-29.3,0
					c-6.3-10.8-19-10.8-25.3,0c-7.4,12.8-21.9,12.8-29.3,0c-6.3-10.8-19-10.8-25.3,0c-7.4,12.8-21.9,12.8-29.3,0
					c-2.3-4-5.5-6.5-8.9-7.6V49c4.2,1.1,8.1,4.1,11,9.1c6.3,10.8,19,10.8,25.3,0c7.4-12.8,21.9-12.8,29.3,0c6.3,10.8,19,10.8,25.3,0
					c7.4-12.8,21.9-12.8,29.3,0c6.3,10.8,19,10.8,25.3,0c7.4-12.8,21.9-12.8,29.3,0c6.3,10.8,19,10.8,25.3,0c3.7-6.4,9.2-9.6,14.6-9.6
					c5.5,0,10.9,3.2,14.6,9.6c6.3,10.8,19,10.8,25.3,0c7.4-12.8,21.9-12.8,29.3,0c6.3,10.8,19,10.8,25.3,0c7.4-12.8,21.9-12.8,29.3,0
					c6.3,10.8,19,10.8,25.3,0c3.7-6.4,9.2-9.6,14.6-9.6c5.5,0,10.9,3.2,14.6,9.6c6.3,10.8,19,10.8,25.3,0c7.4-12.8,21.9-12.8,29.3,0
					c6.3,10.8,19,10.8,25.3,0c7.4-12.8,21.9-12.8,29.3,0c6.3,10.8,19,10.8,25.3,0c7.4-12.8,21.9-12.8,29.3,0c6.3,10.8,19,10.8,25.3,0
					c7.4-12.8,21.9-12.8,29.3,0c6.3,10.8,19,10.8,25.3,0c7.4-12.8,21.9-12.8,29.3,0c6.3,10.8,19,10.8,25.3,0c7.4-12.8,21.9-12.8,29.3,0
					c6.3,10.8,19,10.8,25.3,0c7.4-12.8,21.9-12.8,29.3,0c6.3,10.8,19,10.8,25.3,0c7.4-12.8,21.9-12.8,29.3,0c6.3,10.8,19,10.8,25.3,0
					c7.4-12.8,21.9-12.8,29.3,0c6.3,10.8,19,10.8,25.3,0c7.4-12.8,21.9-12.8,29.3,0c6.3,10.8,19,10.8,25.3,0c7.4-12.8,21.9-12.8,29.3,0
					c1.9,3.2,4.3,5.5,7,6.8v-5.6C996.6,57.8,993.4,55,991,50.9z"/>
			</svg>',
			'paper-torn'      => '<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 1000 80">
				<path d="M0,0V71.07l.22.05c2.83,1,7.45-4.57,7.45-4.57s13.36,6.34,14.9,6.6S30,76.45,30,76.45L36.7,71.5s5.4,6,8,4.95,16.19-8.88,17.73-3.55S64.2,80,65,80s5.4-5.59,6.42-5.59,11,2.79,11.82,2.79,7.71-5.84,9.25-6.6,18.24.51,22.1,2.66,14.13.13,19.79,0,25.18,1.9,25.18,1.9l8.48-1.9s0-5.46,1.8-5.2,9.25.51,9.25.51L180.34,65s20.81,2,22.1,2,2.31-3.81,4.37-3.81,14.13,3.81,15.42,3.81,9.25-3.55,11.56-3.81,8.48,5.08,10.28,5.58,55-6.6,55-6.6-.26-5.33,4.88-3.55,15.16,1.27,19.53,2,3.34,6.34,7.71,2.54,5.65-7.36,8.22-6.09,10.28,2.28,11,2.28,4.37-8.12,7.19-6.6,21.59,12.5,30.06,13.48,13.1-10.44,13.1-10.44l13.1,2.54s7.71,10.15,16.19,11.17,11,6.34,19.27,3.55,17.73-9.39,20-8.38,17.47-6.6,18.24-6.85,8.74.76,16.44.25,9.51-5.52,9.51-5.52,25.69-1.08,28.78,1.21,3.6,4.31,6.68,4.31,12.33-5.84,22.35-3.55,26,6.34,27.49,7.11,10.28-5.58,10.28-5.58,5.14,4.57,6.42,5.84,6.17.76,9.25,0,3.85-9.14,10-5.08,20.3-5.08,25.44,1S667,64,667,64s6.68-11.42,14.39-9.9S710.16,66.2,710.16,66.2l6.42-5.49,27.24-1.27s-1.28-7.11,6.17-5.33,10-.89,11-1.71,5.14-3.49,9,0,25.44,8.31,32.89,8.31,15.93-6.35,22.61-4.57,13.36-1.52,14.39-2-.77-4.65,6.42-3.47,19-.76,20.58-.25,6.17-.76,11.31-1.78,6.34-11.63,12.25-4.27,8.68,5.28,11.51,6.74,7.45,1.33,9.25,0-1.54-7.93,7.19-5.39,4.17,3.48,10.08,3,14.13,4.06,14.13,4.06,10.79-2,13.11-2.28,9.25-4.57,12.59-2.79,6.17,1.52,9,2.28,10-.51,11.82-1.78,2.57-6.35,7.71-3.55a11.91,11.91,0,0,1,3.14,2.18V0Z" fill-opacity=".4"/>
				<path d="M0,0V59.17c4.84-3,4.08,1,5.36-.23s0,0,2.57-1.27,3.08.51,7.19,1,2.83,2.54,2.83,2.54,8.74,5.08,10.28,4.57,4.88-9.14,4.37-10.15S40,61.22,40,61.22l4.37,3.3s9.76,2,11,1a59.11,59.11,0,0,1,8-4.57c1.8-.76,4.11,2.28,6.68,2.79s8.74,3.81,8.74,3.81S90.92,60.71,94,60.21s16.7,3.55,17.47,2,11.82-3,13.1-2.79,8.48,10.91,8.48,10.91l30.83-.51s6.68-6.09,7.45-7.61.26-1.78.26-1.78,9-4.57,10-4.57S193.18,61,193.18,61s10.54-4.06,14.39-5.08,6.68,1.52,12.85-2,19.79-2.79,20.56-3.3,7.45-6.34,12.85-9.39,11.31.76,13.1.76,7.71,5.33,10.79,4.57,10.28-5.33,13.62-5.33,2.83,2.28,10.28,1.78,5.91.51,12.59,4.32,8-2.29,12.85-3.55,1.8.25,4.63-.51a19,19,0,0,1,5.65-.76c1.29,0,2.57,1.52,8.74,3.55s5.91-.76,9.25-1.78,8.22-3.3,18.76-10.15,2.57,5.33,6.94,6.85,22.87,3.55,24.41,2,4.37-3,7.2-4.57,2.82-.51,3.59-.51,9,2.54,11.31,4.06,3.85,4.57,6.17,4.57,4.62-2.54,11-3.55-.26,4.82,0,5.58,2.06,0,5.4-.25,4.88-2.79,9.76-2.79,5.14,3.3,8.48,4.06,2.83,0,10.54-3.81,6.68-1.78,14.9-3.55,22.61,6.85,24.41,6.09,4.88-1.27,11.3-2.54,11.56,3,16.19,5.58,5.14-1.52,8.74-5.08,12.08.25,14.9.25,9.25-.25,13.36-.51,5.14-3,13.88-5.08,8,4.57,14.65,3.55,14.13-1.27,28-5.08,6.42,3,10.79,5.58,9,1.78,11.56,1.52S676,39.65,679.84,36.35s9.51,4.31,16.19,8.12,9.25,3.81,14.13,1.78,9.51-4.82,14.9-7.87,5.4,5.84,10,2.79,15.42.76,17.21-.25,8.48.76,15.42-1,1.8,2,7.45,6.85,3.08-2.29,15.42,1,28.52-2.29,32.89-3,4.88,5.33,9.25,5.84,5.4-4.82,9.76-7.87,17-.76,20.56-2a17.22,17.22,0,0,0,6.17-4.06s13.36,0,15.16-1.52,10.28-.76,13.36-.76,26,4.57,35.2,2.79,11.82-7.62,16.44-10.91,23.13,2.54,30.32,2.54,20.3-2.54,20.3-2.54V0Z"/>
			</svg>',
			'pointy-wave'     => '<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 283 20.99">
				<path d="M0,0V9.75c6.34,1.73,14.2,5,18.57,10.58,14-19.4,49.1-13.44,63.09-1.93,25.76-17.05,52.87-8.45,62.09,2.6,17-17.81,57.8-13.13,70.75-.21,2.62-6.22,39.29-21.54,55-.58,6.79-7,9.64-8.49,13.46-9.21V0Z"/>
			</svg>',
			'rocky-mountain'  => '<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 1000 90.13">
				<path d="M1.32,85.5,5,89c4.08,0,8.7.92,10.42-1.8.65-1,2.85-.1,3.47.39,2.28,1.83,5.49,1.65,9.13.9-.89-2.77,5.72-4.43,6.08-7V80c-2.51-1.16-.53-2.71-2-4-.82-.7.72-1.08,2.35-.56,2.77.9,4.7,2,4.55,3.57l1.23,2c3,1.21,7.24,1.74,10.9,3.83,0-2.07,0-3.42,0-4.78.08-1.52,1.08-2.29,5.11-1.23,4.59,1.2,5.54.89,5.83-1.44.18-1.44-1.68-3.45,4.8-3.4,3.53-1.37,1.65-3.48,4.14-5.11,2.84.26,4.71,1,5.41,2.16,1,1.63,3.26,1.64,6.22,1a4.26,4.26,0,0,1,2.41-.5c1.14-1.13,4.79-1.57,4.86-3-2.14-.93-1-2-.94-3.29,2.88.73,3.33,1.72,3.35,2.8h0c1.47,1.13,2.47,2.42,6.44,2.51,4.19.1,5-1.29,6.61-2.34a.78.78,0,0,1,.3-.19V67c0-1.24-.18-2.79,2.68-3.3s4.19,1,5.8,1.75a8,8,0,0,0,5.74.63c4.21-1.06,9.11-1,13.62-1.6,3.58-.47,7.19-.9,10.71-1.42,5.64-.83,9.44-3,9.35-5.5-.06-1.66.86-3.09,4.2-4.13.14-1,1.71-1.56,3.65-2,2-1,3-2.37,6-3,.35-1.26,2.61-1.88,4.84-2.51h0c.13-1,1.73-1.56,3.64-2a30.2,30.2,0,0,1,11.74-6.72c4.7-1.48,8.37-3.52,12.5-5.31h0c.72-1.38,2.73-2.22,6.08-2.51,3.31-1,7.5-.25,10.91-1l3.65-1c7.44-2.11,13.92-4.87,22.73-6.08,1.77,1.27-3,.69-1.91,1.56,1.33,1,4.25.43,6.42.74-4.15,1.65-8.4,3.08-8.56,5.64,0,.39-1.92.77-3,1.15-1.54.45-4.59.51-4.1,1.51s3.21.59,4.73.46c6.35-.55,6,1.71,7.89,3,3.63.23,7.5-.49,10.92.5h4.82c2.26-2.51,8.06-3.68,12.13-5.5,1.41-.64,2.15-1.66,4.91-1.56,2-1.57,6.22-1.86,9.51-2.69,2.14-.54,4.94-.7,6.2-1.77,4-.36,6.17-1.86,9.65-2.53a35.9,35.9,0,0,1,13.37-3.49l2.35-.53c.13-.63.94-1,2.5-1,2.09-.9,4.74-.35,7.14-.49.61-.33,1.94-.18,2.56-.51,7.62.22,13.94-1.39,20.6-2.51,1.62-.73,3.24.51,4.85,0l6.07,1c1.52.87-.5,1.37-1.22,2h-1.21c-1.14,1.56-4.58,1.23-7.27,1.5a13.82,13.82,0,0,1-2.43,2l-1.21.5c-1,.5-1.53,1,0,1.5a61.32,61.32,0,0,0,14.55-1c1.86-.23,4-.91,4.85.5-1.29,1-3.57,1.33-6.06,1.51-1.6.84-3,1.74-4.86,2.51h0c1.14.3,2.61,1,3.37.84,5.29-.82,6.2.76,7.5,2.17h.06c1.89-.32,2,.38,2.4.95,5,1.26,7-1.3,10.91-1.5,1.76.39,1.76.39,1.22,2.51-2.39.77-2.25,2.3-5.38,2.94,7.74.09,13-2.35,19.92-2.94a1.58,1.58,0,0,1,1.4,0c6.65-.49,13.3-1,20-1.47a14.61,14.61,0,0,0,5.32-1l4.82-.53,2.46-1.44c5.54-.9,9-3.11,14.45-4A43.84,43.84,0,0,1,468,19.28a14.77,14.77,0,0,0,4.84,2c-.1,2.52,4.71,4.24,6.15,6.5,1.72.84,1.85,1.69,0,2.52,0,1.76,2.49,2.08,6,1.75a3.56,3.56,0,0,0,.57-.09c13.41-2.48,27.72-2,41.83-2.19,5.65-.63,11.8-.55,16.89-2l2.56-2.48c9.6-4.55,22.48-6.22,36.3-7.07h0c11.36-4.3,24.1-4,37.28-2.21a7.1,7.1,0,0,1,1.62.22l10.8-.5c5.41-1.69,11.22-.87,17-.47l1.35,1,3.56,1a247.91,247.91,0,0,1,27.83,4.07,8.18,8.18,0,0,0,3.61,1.51l.07.73h.18c1.75.17,3.17.87,5,.8,12.36-.5,19.51,3.19,27.89,5.88a21.12,21.12,0,0,0,4.47,1.21,60.83,60.83,0,0,1,17,4.44l1.2.43c3.44,1.75,7.65,3.21,10.9,5h0c.69.26.78.57.48.91l-.29.09c7.44,2.68,16.07,4.85,21.23,8.54,1.14.81,3.52,1.31,5.32,2H782c6.74-1,13.49-2.07,20.66-2.5v-.49c1.68-.06,3.56.21,4.85-.5,1.68-.06,3.56.21,4.85-.5a61.33,61.33,0,0,0,14.54-1.51l31.52-3.51a249.93,249.93,0,0,1,29.07-1v.49c6.56,1.2,6.65,1.77,2.11,4-2.3,1.12-8.15,1.75-4.56,4.06h1.22c2.43.17,4.85.83,7.28,0,2.16-.12,5.29-1,4.85,1a6.68,6.68,0,0,1-3.11.53c-5.23.17-8.29,1.31-9,3.48.37.22.36.39,0,.51h0l2.44,1.48a46.42,46.42,0,0,1,9.67,2h0c4.5.92,8.41-.69,12.76-.51,2.19.09,4.41,0,6.62,0,.38.11.49.22.38.33a.57.57,0,0,1-.38.17c-.88.91-3.08,1.09-4.85,1.5-3.15.59-6.37,1.11-9.7,1.51l-4.84.5h-1.26c-4,.16-3.61,1.37-3.57,2.51,4.71,1.35,8.83,2.85,8.5,5.53a36.52,36.52,0,0,0,8.43,1.52c3.2.82-.74,2.9,3.65,3.51h2.45c4.21.4,8.32-1.09,13.21-.11-2.68,1-4.47,2.23-8.36,2.12-1.44.37-1.17,1-1.23,1.52.35,2.29,2.23,4,8.6,4.31A25.74,25.74,0,0,1,935.95,86c5.49-.09,10.84.13,16.36-.82,4.77-.82,10.08.48,15.14.84,5.32-.22,10.51.29,15.74.51V87c5.66-.39,5.19,2.17,8.35,3l.13-.09a4.3,4.3,0,0,1,2.45.07l.3.13a1.52,1.52,0,0,1-.1-.31c1.89-.11,3.59-.83,5.68-.36V0H0V84.44A1.82,1.82,0,0,1,1.32,85.5Z" transform="translate(0 -0.01)"/>
			</svg>',
			'single-wave'     => '<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 1000 99">
				<path d="M526.35,17.11C607.41,28.38,687,48.17,768.06,59.5A1149.19,1149.19,0,0,0,1000,68.07V0H0V99C155.18,13.84,347.42-7.77,526.35,17.11Z" transform="translate(0 0.04)"/>
			</svg>',
			'slope-opacity'   => '<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 1000 100">
				<path d="M0,22.3V0H1000V100Z" transform="translate(0 0)" fill-opacity=".4"/>
				<path d="M0,6V0H1000V100Z" transform="translate(0 0)"/>
			</svg>',
			'slope'           => '<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 1000 100">
				<path d="M0,6V0H1000V100Z" transform="translate(0 0)"/>
			</svg>',
			'slope-turning'   => '<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 1000 89">
				<polygon points="0 0 741 89 1000 0 0 0"/>
			</svg>',
			'wavy-opacity'    => '<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 1000 100">
				<path d="M0,0v90.4c60.5,5.6,212,13.2,389.9-25.5c231.4-50.4,346-47.5,459.8-19.6C911.5,60.5,964.5,64.5,1000,65V0H0z"/>
				<path d="M0,0v88.3c39,6,184.6,23.5,383.9-10.2C618.2,38.6,733.1,46.8,846.5,80c63.1,18.5,117.6,16.4,153.5,10.9V0H0z"/>
				<path d="M0,0v91.1c57.5,1.7,189.5-0.3,364.7-39.9C603-2.7,719.9,8.5,835.2,53.7C904.7,81,963.9,91.7,1000,95.8V0H0z"/>
				<path d="M0,0v76.5c35.5,3,92,2.1,157.8-19.8C270.6,19.4,385,10.2,618,54.7c196.4,37.5,341.3,19.2,382,12.6V0H0z"/>
			</svg>',
			'zigzag-shark'    => '<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 1000 100">
				<polygon points="0,0 0,46.7 40.7,23.4 82.5,47.2 124.2,23.4 166,47.2 207.7,23.4 249.4,47.2 291.2,23.4 332.9,47.2 374.7,23.4
				416.4,47.2 458.1,23.4 499.9,47.2 541.6,23.4 583.4,47.2 625.1,23.4 666.9,47.2 708.6,23.4 750.3,47.2 792.1,23.4 833.8,47.2
				875.6,23.4 917.3,47.2 959,23.4 1000,46.8 1000,0 "/>
				<path d="M499.9,51"/>
			</svg>',
		] );
	}
}

if ( ! function_exists( 'gtg_render_shape_background' ) ) {

	/**
	 * print shape divider
	 */
	function gtg_render_shape_background( $name = '' ) {
		static $shapes;
		if ( empty( $shapes ) ) {
			$shapes = gtg_shape_backgrounds();
		}

		return ! empty( $shapes[ $name ] ) ? $shapes[ $name ] : '';
	}

}

if ( ! function_exists( 'gtg_divider_styles' ) ) {
	function gtg_divider_styles() {
		return apply_filters( 'gutengeek_divider_styles', [
			'curly'          => [
				'label'                 => _x( 'Curly', 'shapes', 'gutengeek' ),
				'shape'                 => '<path d="M0,21c3.3,0,8.3-0.9,15.7-7.1c6.6-5.4,4.4-9.3,2.4-10.3c-3.4-1.8-7.7,1.3-7.3,8.8C11.2,20,17.1,21,24,21"/>',
				'preserve_aspect_ratio' => false,
				'supports_amount'       => true,
				'round'                 => false,
				'group'                 => 'line',
			],
			'curved'         => [
				'label'                 => _x( 'Curved', 'shapes', 'gutengeek' ),
				'shape'                 => '<path d="M0,6c6,0,6,13,12,13S18,6,24,6"/>',
				'preserve_aspect_ratio' => false,
				'supports_amount'       => true,
				'round'                 => false,
				'group'                 => 'line',
			],
			'multiple'       => [
				'label'                 => _x( 'Multiple', 'shapes', 'gutengeek' ),
				'shape'                 => '<path d="M24,8v12H0V8H24z M24,4v1H0V4H24z"/>',
				'preserve_aspect_ratio' => false,
				'supports_amount'       => false,
				'round'                 => false,
				'group'                 => 'pattern',
			],
			'slashes'        => [
				'label'                 => _x( 'Slashes', 'shapes', 'gutengeek' ),
				'shape'                 => '<g transform="translate(-12.000000, 0)"><path d="M28,0L10,18"/><path d="M18,0L0,18"/><path d="M48,0L30,18"/><path d="M38,0L20,18"/></g>',
				'preserve_aspect_ratio' => false,
				'supports_amount'       => true,
				'round'                 => false,
				'view_box'              => '0 0 20 16',
				'group'                 => 'line',
			],
			'squared'        => [
				'label'                 => _x( 'Squared', 'shapes', 'gutengeek' ),
				'shape'                 => '<polyline points="0,6 6,6 6,18 18,18 18,6 24,6 	"/>',
				'preserve_aspect_ratio' => false,
				'supports_amount'       => true,
				'round'                 => false,
				'group'                 => 'line',
			],
			'wavy'           => [
				'label'                 => _x( 'Wavy', 'shapes', 'gutengeek' ),
				'shape'                 => '<path d="M0,6c6,0,0.9,11.1,6.9,11.1S18,6,24,6"/>',
				'preserve_aspect_ratio' => false,
				'supports_amount'       => true,
				'round'                 => false,
				'group'                 => 'line',
			],
			'zigzag'         => [
				'label'                 => _x( 'Zigzag', 'shapes', 'gutengeek' ),
				'shape'                 => '<polyline points="0,18 12,6 24,18 "/>',
				'preserve_aspect_ratio' => false,
				'supports_amount'       => true,
				'round'                 => false,
				'group'                 => 'line',
			],
			'arrows'         => [
				'label'                 => _x( 'Arrows', 'shapes', 'gutengeek' ),
				'shape'                 => '<path d="M14.2,4c0.3,0,0.5,0.1,0.7,0.3l7.9,7.2c0.2,0.2,0.3,0.4,0.3,0.7s-0.1,0.5-0.3,0.7l-7.9,7.2c-0.2,0.2-0.4,0.3-0.7,0.3s-0.5-0.1-0.7-0.3s-0.3-0.4-0.3-0.7l0-2.9l-11.5,0c-0.4,0-0.7-0.3-0.7-0.7V9.4C1,9,1.3,8.7,1.7,8.7l11.5,0l0-3.6c0-0.3,0.1-0.5,0.3-0.7S13.9,4,14.2,4z"/>',
				'preserve_aspect_ratio' => true,
				'supports_amount'       => true,
				'round'                 => true,
				'group'                 => 'pattern',
			],
			'pluses'         => [
				'label'                 => _x( 'Pluses', 'shapes', 'gutengeek' ),
				'shape'                 => '<path d="M21.4,9.6h-7.1V2.6c0-0.9-0.7-1.6-1.6-1.6h-1.6c-0.9,0-1.6,0.7-1.6,1.6v7.1H2.6C1.7,9.6,1,10.3,1,11.2v1.6c0,0.9,0.7,1.6,1.6,1.6h7.1v7.1c0,0.9,0.7,1.6,1.6,1.6h1.6c0.9,0,1.6-0.7,1.6-1.6v-7.1h7.1c0.9,0,1.6-0.7,1.6-1.6v-1.6C23,10.3,22.3,9.6,21.4,9.6z"/>',
				'preserve_aspect_ratio' => true,
				'supports_amount'       => true,
				'round'                 => false,
				'group'                 => 'pattern',
			],
			'rhombus'        => [
				'label'                 => _x( 'Rhombus', 'shapes', 'gutengeek' ),
				'shape'                 => '<path d="M12.7,2.3c-0.4-0.4-1.1-0.4-1.5,0l-8,9.1c-0.3,0.4-0.3,0.9,0,1.2l8,9.1c0.4,0.4,1.1,0.4,1.5,0l8-9.1c0.3-0.4,0.3-0.9,0-1.2L12.7,2.3z"/>',
				'preserve_aspect_ratio' => false,
				'supports_amount'       => true,
				'round'                 => false,
				'group'                 => 'pattern',
			],
			'parallelogram'  => [
				'label'                 => _x( 'Parallelogram', 'shapes', 'gutengeek' ),
				'shape'                 => '<polygon points="9.4,2 24,2 14.6,21.6 0,21.6"/>',
				'preserve_aspect_ratio' => false,
				'supports_amount'       => true,
				'round'                 => false,
				'group'                 => 'pattern',
			],
			'rectangles'     => [
				'label'                 => _x( 'Rectangles', 'shapes', 'gutengeek' ),
				'shape'                 => '<rect x="15" y="0" width="30" height="30"/>',
				'preserve_aspect_ratio' => false,
				'supports_amount'       => true,
				'round'                 => true,
				'group'                 => 'pattern',
				'view_box'              => '0 0 60 30',
			],
			'dots_tribal'    => [
				'label'                 => _x( 'Dots', 'shapes', 'gutengeek' ),
				'shape'                 => '<path d="M3,10.2c2.6,0,2.6,2,2.6,3.2S4.4,16.5,3,16.5s-3-1.4-3-3.2S0.4,10.2,3,10.2z M18.8,10.2c1.7,0,3.2,1.4,3.2,3.2s-1.4,3.2-3.2,3.2c-1.7,0-3.2-1.4-3.2-3.2S17,10.2,18.8,10.2z M34.6,10.2c1.5,0,2.6,1.4,2.6,3.2s-0.5,3.2-1.9,3.2c-1.5,0-3.4-1.4-3.4-3.2S33.1,10.2,34.6,10.2z M50.5,10.2c1.7,0,3.2,1.4,3.2,3.2s-1.4,3.2-3.2,3.2c-1.7,0-3.3-0.9-3.3-2.6S48.7,10.2,50.5,10.2z M66.2,10.2c1.5,0,3.4,1.4,3.4,3.2s-1.9,3.2-3.4,3.2c-1.5,0-2.6-0.4-2.6-2.1S64.8,10.2,66.2,10.2z M82.2,10.2c1.7,0.8,2.6,1.4,2.6,3.2s-0.1,3.2-1.6,3.2c-1.5,0-3.7-1.4-3.7-3.2S80.5,9.4,82.2,10.2zM98.6,10.2c1.5,0,2.6,0.4,2.6,2.1s-1.2,4.2-2.6,4.2c-1.5,0-3.7-0.4-3.7-2.1S97.1,10.2,98.6,10.2z M113.4,10.2c1.2,0,2.2,0.9,2.2,3.2s-0.1,3.2-1.3,3.2s-3.1-1.4-3.1-3.2S112.2,10.2,113.4,10.2z"/>',
				'preserve_aspect_ratio' => true,
				'supports_amount'       => false,
				'round'                 => false,
				'group'                 => 'tribal',
				'view_box'              => '0 0 126 26',
			],
			'trees_2_tribal' => [
				'label'                 => _x( 'Fir Tree', 'shapes', 'gutengeek' ),
				'shape'                 => '<path d="M111.9,18.3v3.4H109v-3.4H111.9z M90.8,18.3v3.4H88v-3.4H90.8z M69.8,18.3v3.4h-2.9v-3.4H69.8z M48.8,18.3v3.4h-2.9v-3.4H48.8z M27.7,18.3v3.4h-2.9v-3.4H27.7z M6.7,18.3v3.4H3.8v-3.4H6.7z M46.4,4l4.3,4.8l-1.8,0l3.5,4.4l-2.2-0.1l3,3.3l-11,0.4l3.6-3.8l-2.9-0.1l3.1-4.2l-1.9,0L46.4,4z M111.4,4l2.4,4.8l-1.8,0l3.5,4.4l-2.5-0.1l3.3,3.3h-11l3.1-3.4l-2.5-0.1l3.1-4.2l-1.9,0L111.4,4z M89.9,4l2.9,4.8l-1.9,0l3.2,4.2l-2.5,0l3.5,3.5l-11-0.4l3-3.1l-2.4,0L88,8.8l-1.9,0L89.9,4z M68.6,4l3,4.4l-1.9,0.1l3.4,4.1l-2.7,0.1l3.8,3.7H63.8l2.9-3.6l-2.9,0.1L67,8.7l-2,0.1L68.6,4z M26.5,4l3,4.4l-1.9,0.1l3.7,4.7l-2.5-0.1l3.3,3.3H21l3.1-3.4l-2.5-0.1l3.2-4.3l-2,0.1L26.5,4z M4.9,4l3.7,4.8l-1.5,0l3.1,4.2L7.6,13l3.4,3.4H0l3-3.3l-2.3,0.1l3.5-4.4l-2.3,0L4.9,4z"/>',
				'preserve_aspect_ratio' => true,
				'supports_amount'       => false,
				'round'                 => false,
				'group'                 => 'tribal',
				'view_box'              => '0 0 126 26',
			],
			'rounds_tribal'  => [
				'label'                 => _x( 'Half Rounds', 'shapes', 'gutengeek' ),
				'shape'                 => '<path d="M11.9,15.9L11.9,15.9L0,16c-0.2-3.7,1.5-5.7,4.9-6C10,9.6,12.4,14.2,11.9,15.9zM26.9,15.9L26.9,15.9L15,16c0.5-3.7,2.5-5.7,5.9-6C26,9.6,27.4,14.2,26.9,15.9z M37.1,10c3.4,0.3,5.1,2.3,4.9,6H30.1C29.5,14.4,31.9,9.6,37.1,10z M57,15.9L57,15.9L45,16c0-3.4,1.6-5.4,4.9-5.9C54.8,9.3,57.4,14.2,57,15.9z M71.9,15.9L71.9,15.9L60,16c-0.2-3.7,1.5-5.7,4.9-6C70,9.6,72.4,14.2,71.9,15.9z M82.2,10c3.4,0.3,5,2.3,4.8,6H75.3C74,13,77.1,9.6,82.2,10zM101.9,15.9L101.9,15.9L90,16c-0.2-3.7,1.5-5.7,4.9-6C100,9.6,102.4,14.2,101.9,15.9z M112.1,10.1c2.7,0.5,4.3,2.5,4.9,5.9h-11.9l0,0C104.5,14.4,108,9.3,112.1,10.1z"/>',
				'preserve_aspect_ratio' => true,
				'supports_amount'       => false,
				'round'                 => false,
				'group'                 => 'tribal',
				'view_box'              => '0 0 120 26',
			],
			'leaves_tribal'  => [
				'label'                 => _x( 'Leaves', 'shapes', 'gutengeek' ),
				'shape'                 => '<path d="M3,1.5C5,4.9,6,8.8,6,13s-1.7,8.1-5,11.5C0.3,21.1,0,17.2,0,13S1,4.9,3,1.5z M16,1.5c2,3.4,3,7.3,3,11.5s-1,8.1-3,11.5c-2-4.1-3-8.3-3-12.5S14,4.3,16,1.5z M29,1.5c2,4.8,3,9.3,3,13.5s-1,7.4-3,9.5c-2-3.4-3-7.3-3-11.5S27,4.9,29,1.5z M41.1,1.5C43.7,4.9,45,8.8,45,13s-1,8.1-3,11.5c-2-3.4-3-7.3-3-11.5S39.7,4.9,41.1,1.5zM55,1.5c2,2.8,3,6.3,3,10.5s-1.3,8.4-4,12.5c-1.3-3.4-2-7.3-2-11.5S53,4.9,55,1.5z M68,1.5c2,3.4,3,7.3,3,11.5s-0.7,8.1-2,11.5c-2.7-4.8-4-9.3-4-13.5S66,3.6,68,1.5z M82,1.5c1.3,4.8,2,9.3,2,13.5s-1,7.4-3,9.5c-2-3.4-3-7.3-3-11.5S79.3,4.9,82,1.5z M94,1.5c2,3.4,3,7.3,3,11.5s-1.3,8.1-4,11.5c-1.3-1.4-2-4.3-2-8.5S92,6.9,94,1.5z M107,1.5c2,2.1,3,5.3,3,9.5s-0.7,8.7-2,13.5c-2.7-3.4-4-7.3-4-11.5S105,4.9,107,1.5z"/>',
				'preserve_aspect_ratio' => true,
				'supports_amount'       => false,
				'round'                 => false,
				'group'                 => 'tribal',
				'view_box'              => '0 0 117 26',
			],
			'stripes_tribal' => [
				'label'                 => _x( 'Stripes', 'shapes', 'gutengeek' ),
				'shape'                 => '<path d="M54,1.6V26h-9V2.5L54,1.6z M69,1.6v23.3L60,26V1.6H69z M24,1.6v23.5l-9-0.6V1.6H24z M30,0l9,0.7v24.5h-9V0z M9,2.5v22H0V3.7L9,2.5z M75,1.6l9,0.9v22h-9V1.6z M99,2.7v21.7h-9V3.8L99,2.7z M114,3.8v20.7l-9-0.5V3.8L114,3.8z"/>',
				'preserve_aspect_ratio' => true,
				'supports_amount'       => false,
				'round'                 => false,
				'group'                 => 'tribal',
				'view_box'              => '0 0 120 26',
			],
			'squares_tribal' => [
				'label'                 => _x( 'Squares', 'shapes', 'gutengeek' ),
				'shape'                 => '<path d="M46.8,7.8v11.5L36,18.6V7.8H46.8z M82.4,7.8L84,18.6l-12,0.7L70.4,7.8H82.4z M0,7.8l12,0.9v9.9H1.3L0,7.8z M30,7.8v10.8H19L18,7.8H30z M63.7,7.8L66,18.6H54V9.5L63.7,7.8z M89.8,7L102,7.8v10.8H91.2L89.8,7zM108,7.8l12,0.9v8.9l-12,1V7.8z"/>',
				'preserve_aspect_ratio' => true,
				'supports_amount'       => false,
				'round'                 => false,
				'group'                 => 'tribal',
				'view_box'              => '0 0 126 26',
			],
			'trees_tribal'   => [
				'label'                 => _x( 'Trees', 'shapes', 'gutengeek' ),
				'shape'                 => '<path d="M6.4,2l4.2,5.7H7.7v2.7l3.8,5.2l-3.8,0v7.8H4.8v-7.8H0l4.8-5.2V7.7H1.1L6.4,2z M25.6,2L31,7.7h-3.7v2.7l4.8,5.2h-4.8v7.8h-2.8v-7.8l-3.8,0l3.8-5.2V7.7h-2.9L25.6,2z M47.5,2l4.2,5.7h-3.3v2.7l3.8,5.2l-3.8,0l0.4,7.8h-2.8v-7.8H41l4.8-5.2V7.7h-3.7L47.5,2z M66.2,2l5.4,5.7h-3.7v2.7l4.8,5.2h-4.8v7.8H65v-7.8l-3.8,0l3.8-5.2V7.7h-2.9L66.2,2zM87.4,2l4.8,5.7h-2.9v3.1l3.8,4.8l-3.8,0v7.8h-2.8v-7.8h-4.8l4.8-4.8V7.7h-3.7L87.4,2z M107.3,2l5.4,5.7h-3.7v2.7l4.8,5.2h-4.8v7.8H106v-7.8l-3.8,0l3.8-5.2V7.7h-2.9L107.3,2z"/>',
				'preserve_aspect_ratio' => true,
				'supports_amount'       => false,
				'round'                 => false,
				'group'                 => 'tribal',
				'view_box'              => '0 0 123 26',
			],
			'planes_tribal'  => [
				'label'                 => _x( 'Tribal', 'shapes', 'gutengeek' ),
				'shape'                 => '<path d="M29.6,10.3l2.1,2.2l-3.6,3.3h7v2.9h-7l3.6,3.5l-2.1,1.7l-5.2-5.2h-5.8v-2.9h5.8L29.6,10.3z M70.9,9.6l2.1,1.7l-3.6,3.5h7v2.9h-7l3.6,3.3l-2.1,2.2l-5.2-5.5h-5.8v-2.9h5.8L70.9,9.6z M111.5,9.6l2.1,1.7l-3.6,3.5h7v2.9h-7l3.6,3.3l-2.1,2.2l-5.2-5.5h-5.8v-2.9h5.8L111.5,9.6z M50.2,2.7l2.1,1.7l-3.6,3.5h7v2.9h-7l3.6,3.3l-2.1,2.2L45,10.7h-5.8V7.9H45L50.2,2.7z M11,2l2.1,1.7L9.6,7.2h7V10h-7l3.6,3.3L11,15.5L5.8,10H0V7.2h5.8L11,2z M91.5,2l2.1,2.2l-3.6,3.3h7v2.9h-7l3.6,3.5l-2.1,1.7l-5.2-5.2h-5.8V7.5h5.8L91.5,2z"/>',
				'preserve_aspect_ratio' => true,
				'supports_amount'       => false,
				'round'                 => false,
				'group'                 => 'tribal',
				'view_box'              => '0 0 121 26',
			],
			'x_tribal'       => [
				'label'                 => _x( 'X', 'shapes', 'gutengeek' ),
				'shape'                 => '<path d="M10.7,6l2.5,2.6l-4,4.3l4,5.4l-2.5,1.9l-4.5-5.2l-3.9,4.2L0.7,17L4,13.1L0,8.6l2.3-1.3l3.9,3.9L10.7,6z M23.9,6.6l4.2,4.5L32,7.2l2.3,1.3l-4,4.5l3.2,3.9L32,19.1l-3.9-3.3l-4.5,4.3l-2.5-1.9l4.4-5.1l-4.2-3.9L23.9,6.6zM73.5,6L76,8.6l-4,4.3l4,5.4l-2.5,1.9l-4.5-5.2l-3.9,4.2L63.5,17l4.1-4.7L63.5,8l2.3-1.3l4.1,3.6L73.5,6z M94,6l2.5,2.6l-4,4.3l4,5.4L94,20.1l-3.9-5l-3.9,4.2L84,17l3.2-3.9L84,8.6l2.3-1.3l3.2,3.9L94,6z M106.9,6l4.5,5.1l3.9-3.9l2.3,1.3l-4,4.5l3.2,3.9l-1.6,2.1l-3.9-4.2l-4.5,5.2l-2.5-1.9l4-5.4l-4-4.3L106.9,6z M53.1,6l2.5,2.6l-4,4.3l4,4.6l-2.5,1.9l-4.5-4.5l-3.5,4.5L43.1,17l3.2-3.9l-4-4.5l2.3-1.3l3.9,3.9L53.1,6z"/>',
				'preserve_aspect_ratio' => true,
				'supports_amount'       => false,
				'round'                 => false,
				'group'                 => 'tribal',
				'view_box'              => '0 0 126 26',
			],
			'zigzag_tribal'  => [
				'label'                 => _x( 'Zigzag', 'shapes', 'gutengeek' ),
				'shape'                 => '<polygon points="0,14.4 0,21 11.5,12.4 21.3,20 30.4,11.1 40.3,20 51,12.4 60.6,20 69.6,11.1 79.3,20 90.1,12.4 99.6,20 109.7,11.1 120,21 120,14.4 109.7,5 99.6,13 90.1,5 79.3,14.5 71,5.7 60.6,12.4 51,5 40.3,14.5 31.1,5 21.3,13 11.5,5 	"/>',
				'preserve_aspect_ratio' => true,
				'supports_amount'       => false,
				'round'                 => false,
				'group'                 => 'tribal',
				'view_box'              => '0 0 120 26',
			],
		] );
	}
}
if ( ! function_exists( 'gtg_get_color_presets' ) ) {

	/**
	 * get color presets
	 */
	function gtg_get_color_presets() {
		return apply_filters( 'gutengeek_blocks_plugin_color_presets', [
			[ 'name' => 'preset1', 'slug' => 'preset1', 'color' => '#ff1818' ],
			[ 'name' => 'preset2', 'slug' => 'preset2', 'color' => '#456bed' ],
			[ 'name' => 'preset3', 'slug' => 'preset3', 'color' => '#30ac3d' ],
			[ 'name' => 'preset4', 'slug' => 'preset4', 'color' => '#fa9200' ],
			[ 'name' => 'preset5', 'slug' => 'preset5', 'color' => '#006fbf' ],
			[ 'name' => 'preset6', 'slug' => 'preset6', 'color' => '#941f90' ],
		] );
	}

}

if ( ! function_exists( 'gtg_get_button_styles' ) ) {

	/**
	 * get color presets
	 */
	function gtg_get_button_styles() {
		return apply_filters( 'gutengeek_blocks_plugin_button_styles', [
			[ 'value' => 'default', 'label' => __( 'Default' ) ],
			[ 'value' => 'info', 'label' => __( 'Info' ) ],
			[ 'value' => 'success', 'label' => __( 'Success' ) ],
			[ 'value' => 'warning', 'label' => __( 'Warning' ) ],
			[ 'value' => 'danger', 'label' => __( 'Danger' ) ],
			[ 'value' => 'primary', 'label' => __( 'Primary' ) ],
			[ 'value' => 'secondary', 'label' => __( 'Secondary' ) ],
			[ 'value' => 'link', 'label' => __( 'Link' ) ],
		] );
	}
}

if ( ! function_exists( 'gtg_global_setting_name' ) ) {

	function gtg_global_setting_name( $name = '', $default = false ) {
		$settings = gtg_advanced_blocks()->global_settings ? gtg_advanced_blocks()->global_settings : [];

		return isset( $settings[ $name ] ) ? $settings[ $name ] : $default;
	}

}

if ( ! function_exists( 'gtg_setup_sse_event' ) )  {

	function gtg_setup_sse_event() {
		// Start the event stream.
		header( 'Content-Type: text/event-stream, charset=UTF-8' );
		header( 'Cache-Control: no-cache' );

		// Turn off PHP output compression.
		$previous = error_reporting( error_reporting() ^ E_WARNING );
		ini_set( 'output_buffering', 'off' );
		ini_set( 'zlib.output_compression', false );
		error_reporting( $previous );

		if ( $GLOBALS['is_nginx'] ) {
			// Setting this header instructs Nginx to disable fastcgi_buffering and disable gzip for this request.
			header( 'X-Accel-Buffering: no' );
			header( 'Content-Encoding: none' );
		}

		// 2KB padding for IE
		echo ':' . str_repeat( ' ', 2048 ) . "\n\n";

		if ( ! defined( 'WP_CLI' ) ) {
			set_time_limit( 0 );

			// Ensure we're not buffered.
			wp_ob_end_flush_all();
			flush();
		}
	}
}

if ( ! function_exists( 'gtg_emit_sse_event' ) ) {

	/**
	 * sse emit message
	 */
	function gtg_emit_sse_event( $data = [] ) {
		if ( ! defined( 'WP_CLI' ) ) {
			echo "event: message\n";
			echo 'data: ' . wp_json_encode( $data ) . "\n\n";

			// Extra padding.
			echo ':' . str_repeat( ' ', 2048 ) . "\n\n";
		}

		flush();
	}

}

if ( ! function_exists( 'gtg_get_saved_items' ) ) {

	/**
	 * get all saved blocks items
	 */
	function gtg_get_saved_items() {
		$args = [
			'post_type' => 'wp_block',
			'post_status' => 'publish',
			'posts_per_page' => -1,
			'meta_query' => [
				'relation' => 'AND',
				[
					'key' => '_gutengeek_imported_id',
					'compare' => 'EXISTS'
				],
				[
					'key' => '_gutengeek_imported_type',
					'compare' => 'EXISTS'
				],
			]
		];

		$blocks = get_posts( apply_filters( 'gutengeek_get_saved_items_query', $args ) );
		$items = [];
		foreach ( $blocks as $block ) {
			$data = [
				'id' => get_post_meta( $block->ID, '_gutengeek_imported_id', true ),
				'local_id' => $block->ID,
				'type' => get_post_meta( $block->ID, '_gutengeek_imported_type', true ),
				'name' => $block->post_title,
				'source' => 'local',
				'content' => $block->post_content,
				'date' => date_i18n( get_option( 'date_format' ), strtotime( get_post_field( 'post_date', $block->ID ) ) ),
			];

			$items[] = $data;
		}

		return apply_filters( 'gutengeek_saved_blocks', $items );

	}

}

if ( ! function_exists( 'gtg_is_remote_item_saved' ) ) {

	/**
	 * check remote post id is saved before?
	 *
	 * @return bool
	 */
	function gtg_is_remote_item_saved( $tmp_id = false ) {
		$args = [
			'post_type' => 'wp_block',
			'post_status' => 'publish',
			'posts_per_page' => -1,
			'meta_query' => [
				'relation' => 'AND',
				[
					'key' => '_gutengeek_imported_id',
					'compare' => '=',
					'value' => $tmp_id
				]
			]
		];
		$posts = get_posts( apply_filters( 'gutengeek_check_item_saved_query', $args ) );
		return apply_filters( 'gtg_is_remote_item_saved', count( $posts ) > 0 );
	}

}

if ( ! function_exists( 'gtg_get_custom_fonts' ) ) {

	/**
	 * get custom fonts uploaded before
	 *
	 * @since 1.0.0
	 * @return array
	 */
	function gtg_get_custom_fonts() {
		global $wpdb;
		$font_ids = $wpdb->get_col( $wpdb->prepare(
			"SELECT font_id FROM {$wpdb->prefix}gtg_block_fonts WHERE font_status = %s", 'publish'
		) );

		$font_data = [];
		foreach ($font_ids as $id) {
			$font_data[] = gtg_get_font_data($id);
		}
		return apply_filters( 'gutengeek_custom_fonts_loaded', $font_data );
	}

}

if ( ! function_exists( 'gtg_get_font_data' ) ) {

	/**
	 * get single font data
	 *
	 * @return mixed | array | WP_Error
	 */
	function gtg_get_font_data( $font_id = false ) {
		if ( ! $font_id ) {
			return $font_data = [];
		} else {
			global $wpdb;
			$query = $wpdb->prepare( "SELECT * FROM {$wpdb->prefix}gtg_block_fonts WHERE font_id = %d", $font_id );
			$font_data = $wpdb->get_row( $query, ARRAY_A );
			if ( ! $font_data ) {
				return new WP_Error( __( 'Font not found.' ) );
			}

			$query = $wpdb->prepare( "SELECT * FROM {$wpdb->prefix}gtg_block_font_items WHERE font_id = %d", $font_id );
			$font_items = $wpdb->get_results( $query, ARRAY_A );
			if ( $font_items ) {
				// each items
				foreach ( $font_items as $k => $font_item ) {
					$font_item_id = $font_item['font_item_id'];
					// each font files
					$query = $wpdb->prepare( "SELECT * FROM {$wpdb->prefix}gtg_block_font_item_attachments WHERE font_item_id = %d", $font_item_id );
					$files = $wpdb->get_results($query, ARRAY_A);
					foreach ( $files as $key => &$file ) {
						$font_attach_id = ! empty($file['font_attach_id']) ? $file['font_attach_id'] : '';
						$file['url'] = wp_get_attachment_url($font_attach_id);
					}
					$font_item['items'] = $files;
					$font_items[$k] = $font_item;
				}
				$font_data['items'] = $font_items;
			}
		}

		return apply_filters( 'gutengeek_font_data', $font_data, $font_id );
	}

}

if ( ! function_exists( 'gtg_get_custom_icons' ) ) {
	function gtg_get_custom_icons() {
		return get_option( Gtg_Advanced_Blocks\Modules\CustomIcons::OPTION_NAME, [] );
	}
}

if ( ! function_exists( 'gtg_get_icon_data' ) ) {

	/**
	 * get single icon data
	 *
	 * @return mixed | array | WP_Error
	 */
	function gtg_get_icon_data( $icon_id = false ) {
		if ( ! $icon_id ) {
			return [];
		} else {
			global $wpdb;
			$query = $wpdb->prepare( "SELECT * FROM {$wpdb->prefix}gtg_block_icons WHERE icon_id = %d", $icon_id );
			$icon_data = $wpdb->get_row( $query, ARRAY_A );
			if ( ! $icon_data ) {
				return new WP_Error( __( 'Icon not found.', 'gutengeek' ) );
			}
		}

		return apply_filters( 'gutengeek_icon_data', $icon_data, $icon_id );
	}
}

if ( ! function_exists( 'gtg_font_name_exists' ) ) {
	/**
	 * check font exists by name
	 *
	 * @return int if its already exists, false otherwise
	 */
	function gtg_font_name_exists( $font_name = '' ) {
		global $wpdb;
		$query = $wpdb->prepare( "SELECT {$wpdb->prefix}gtg_block_fonts WHERE font_name = %s", $font_name );
		return apply_filters( 'gtg_font_name_exists', $wpdb->get_var($query) );
	}
}

add_filter( 'upload_mimes', 'gtg_upload_addition_mimes', 1, 1 );
if ( ! function_exists( 'gtg_upload_addition_mimes' ) ) {
	function gtg_upload_addition_mimes( $mime_types ) {
		// $mime_types['json'] = 'application/json';
		$mime_types['svg'] = 'image/svg+xml';
		$mime_types['otf'] = 'application/x-font-otf'; //application/vnd.ms-opentype
		$mime_types['woff'] = 'application/x-font-woff';
		$mime_types['woff2'] = 'application/x-font-woff2';//|application/octet-stream|font/x-woff2
		$mime_types['ttf'] = 'application/x-font-ttf';
		$mime_types['eot'] = 'application/vnd.ms-fontobject';

		return $mime_types;
	}

}


if ( ! function_exists( 'gtg_get_setting' ) ) {

	/**
	 * get global settings
	 */
	function gtg_get_setting( $name = '', $default = '') {
		$settings = gtg_advanced_blocks()->get_settings();
		$value = ! empty( $settings[ $name ] ) ? $settings[ $name ] : $default;
		return apply_filters( 'gtg_get_setting', $value );
	}

}

if ( ! function_exists( 'gtg_get_sm_breakpoint_setting' ) ) {

	/**
	 * get sm breakpoints settings
	 */
	function gtg_get_sm_breakpoint_setting() {
		return apply_filters( 'gtg_get_sm_breakpoint_setting', gtg_get_setting( 'sm_breakpoint', GTG_AB_SM_BREAKPOINT ) );
	}

}

if ( ! function_exists( 'gtg_get_xs_breakpoint_setting' ) ) {

	/**
	 * get xs breakpoints settings
	 */
	function gtg_get_xs_breakpoint_setting() {
		return apply_filters( 'gtg_get_xs_breakpoint_setting', gtg_get_setting( 'sm_breakpoint', GTG_AB_XS_BREAKPOINT ) );
	}

}

if ( ! function_exists( 'gtg_masks_presets' ) ) {
	/**
	 * define mask presets
	 */
	function gtg_masks_presets() {
		return apply_filters( 'gutengeek_masks_presets', [
	 		[
	 			'name' => __('Mask 01', 'gutengeek'),
	 			'slug' => 'mask-01',
	 			'url' => GTG_AB_URL . 'assets/images/masks/mask-01.svg',
	 			'string' => ''
	 		],
	 		[
	 			'name' => __('Mask 02', 'gutengeek'),
	 			'slug' => 'mask-02',
	 			'url' => GTG_AB_URL . 'assets/images/masks/mask-02.svg',
	 			'string' => ''
	 		],
	 		[
	 			'name' => __('Mask 03', 'gutengeek'),
	 			'slug' => 'mask-03',
	 			'url' => GTG_AB_URL . 'assets/images/masks/mask-03.svg',
	 			'string' => ''
	 		],
	 		[
	 			'name' => __('Mask 04', 'gutengeek'),
	 			'slug' => 'mask-04',
	 			'url' => GTG_AB_URL . 'assets/images/masks/mask-04.svg',
	 			'string' => ''
	 		]
	 	] );
	}
}
